"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 4581218c84c1

from __future__ import annotations
from mistralai.client.types import BaseModel
import pydantic
from pydantic import ConfigDict
from typing import Any, Dict, List
from typing_extensions import TypedDict


class ConversationPayloadTypedDict(TypedDict):
    messages: List[Dict[str, Any]]


class ConversationPayload(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    messages: List[Dict[str, Any]]

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]
