"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cee4e4197372

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class GetSignedURLResponseTypedDict(TypedDict):
    url: str


class GetSignedURLResponse(BaseModel):
    url: str
