"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f063656f22ae

from __future__ import annotations
from .workflowregistrationwithworkerstatus import (
    WorkflowRegistrationWithWorkerStatus,
    WorkflowRegistrationWithWorkerStatusTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowRegistrationGetResponseTypedDict(TypedDict):
    workflow_registration: WorkflowRegistrationWithWorkerStatusTypedDict
    workflow_version: WorkflowRegistrationWithWorkerStatusTypedDict


class WorkflowRegistrationGetResponse(BaseModel):
    workflow_registration: WorkflowRegistrationWithWorkerStatus

    workflow_version: WorkflowRegistrationWithWorkerStatus
