"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a1bace5342e6

from __future__ import annotations
from .updatejudgerequest import UpdateJudgeRequest, UpdateJudgeRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateJudgeV1ObservabilityJudgesJudgeIDPutRequestTypedDict(TypedDict):
    judge_id: str
    update_judge_request: UpdateJudgeRequestTypedDict


class UpdateJudgeV1ObservabilityJudgesJudgeIDPutRequest(BaseModel):
    judge_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_judge_request: Annotated[
        UpdateJudgeRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
