"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 12635cd17417

from __future__ import annotations
from .failure import Failure, FailureTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ActivityTaskFailedAttributesTypedDict(TypedDict):
    r"""Attributes for activity task failed events (final failure after all retries)."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""
    activity_name: str
    r"""The registered name of the activity being executed."""
    attempt: int
    r"""The final attempt number that failed (1-indexed)."""
    failure: FailureTypedDict
    r"""Represents an error or exception that occurred during execution."""


class ActivityTaskFailedAttributes(BaseModel):
    r"""Attributes for activity task failed events (final failure after all retries)."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""

    activity_name: str
    r"""The registered name of the activity being executed."""

    attempt: int
    r"""The final attempt number that failed (1-indexed)."""

    failure: Failure
    r"""Represents an error or exception that occurred during execution."""
