"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cdb07c3837f7

from __future__ import annotations
from .tooltype import ToolType
from .turbinetoollocale import TurbineToolLocale, TurbineToolLocaleTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class TurbineToolMetaTypedDict(TypedDict):
    locale: NotRequired[Nullable[TurbineToolLocaleTypedDict]]
    tool_type: NotRequired[Nullable[ToolType]]
    timeout: NotRequired[Nullable[float]]
    private_execution: NotRequired[Nullable[bool]]


class TurbineToolMeta(BaseModel):
    locale: OptionalNullable[TurbineToolLocale] = UNSET

    tool_type: OptionalNullable[ToolType] = UNSET

    timeout: OptionalNullable[float] = UNSET

    private_execution: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["locale", "tool_type", "timeout", "private_execution"])
        nullable_fields = set(["locale", "tool_type", "timeout", "private_execution"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
