"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b2e92f2a29b4

from __future__ import annotations
from .filepurpose import FilePurpose
from .sampletype import SampleType
from .source import Source
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FilesAPIRoutesListFilesRequestTypedDict(TypedDict):
    page: NotRequired[int]
    page_size: NotRequired[int]
    include_total: NotRequired[bool]
    sample_type: NotRequired[Nullable[List[SampleType]]]
    source: NotRequired[Nullable[List[Source]]]
    search: NotRequired[Nullable[str]]
    purpose: NotRequired[Nullable[FilePurpose]]
    mimetypes: NotRequired[Nullable[List[str]]]


class FilesAPIRoutesListFilesRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100

    include_total: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = True

    sample_type: Annotated[
        OptionalNullable[List[SampleType]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    source: Annotated[
        OptionalNullable[List[Source]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    search: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    purpose: Annotated[
        OptionalNullable[FilePurpose],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    mimetypes: Annotated[
        OptionalNullable[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "page",
                "page_size",
                "include_total",
                "sample_type",
                "source",
                "search",
                "purpose",
                "mimetypes",
            ]
        )
        nullable_fields = set(
            ["sample_type", "source", "search", "purpose", "mimetypes"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
