"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 24138e419fae

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class VoiceResponseTypedDict(TypedDict):
    r"""Schema for voice response"""

    name: str
    id: str
    created_at: datetime
    user_id: Nullable[str]
    slug: NotRequired[Nullable[str]]
    languages: NotRequired[List[str]]
    gender: NotRequired[Nullable[str]]
    age: NotRequired[Nullable[int]]
    tags: NotRequired[Nullable[List[str]]]
    color: NotRequired[Nullable[str]]
    retention_notice: NotRequired[int]


class VoiceResponse(BaseModel):
    r"""Schema for voice response"""

    name: str

    id: str

    created_at: datetime

    user_id: Nullable[str]

    slug: OptionalNullable[str] = UNSET

    languages: Optional[List[str]] = None

    gender: OptionalNullable[str] = UNSET

    age: OptionalNullable[int] = UNSET

    tags: OptionalNullable[List[str]] = UNSET

    color: OptionalNullable[str] = UNSET

    retention_notice: Optional[int] = 30

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["slug", "languages", "gender", "age", "tags", "color", "retention_notice"]
        )
        nullable_fields = set(["slug", "gender", "age", "tags", "color", "user_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
