"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 62d6a6a13288

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


EntityType = Union[
    Literal[
        "User",
        "Workspace",
        "Org",
    ],
    UnrecognizedStr,
]
r"""The type of entity, used to share a library."""
