"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3e2249825144

from __future__ import annotations
from .workflowexecutionrequest import (
    WorkflowExecutionRequest,
    WorkflowExecutionRequestTypedDict,
)
from .workflowexecutionresponse import (
    WorkflowExecutionResponse,
    WorkflowExecutionResponseTypedDict,
)
from .workflowexecutionsyncresponse import (
    WorkflowExecutionSyncResponse,
    WorkflowExecutionSyncResponseTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class ExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePostRequestTypedDict(
    TypedDict
):
    workflow_registration_id: str
    workflow_execution_request: WorkflowExecutionRequestTypedDict


class ExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePostRequest(
    BaseModel
):
    workflow_registration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    workflow_execution_request: Annotated[
        WorkflowExecutionRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


ResponseExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePostTypedDict = TypeAliasType(
    "ResponseExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePostTypedDict",
    Union[WorkflowExecutionSyncResponseTypedDict, WorkflowExecutionResponseTypedDict],
)
r"""Successful Response"""


ResponseExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePost = TypeAliasType(
    "ResponseExecuteWorkflowRegistrationV1WorkflowsRegistrationsWorkflowRegistrationIDExecutePost",
    Union[WorkflowExecutionSyncResponse, WorkflowExecutionResponse],
)
r"""Successful Response"""
