"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a958f3e6b122

from __future__ import annotations
from .judgeconversationrequest import (
    JudgeConversationRequest,
    JudgeConversationRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class JudgeConversationV1ObservabilityJudgesJudgeIDLiveJudgingPostRequestTypedDict(
    TypedDict
):
    judge_id: str
    judge_conversation_request: JudgeConversationRequestTypedDict


class JudgeConversationV1ObservabilityJudgesJudgeIDLiveJudgingPostRequest(BaseModel):
    judge_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    judge_conversation_request: Annotated[
        JudgeConversationRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
