"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 98c823e7cc1b

from __future__ import annotations
from .judgechatcompletioneventrequest import (
    JudgeChatCompletionEventRequest,
    JudgeChatCompletionEventRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class JudgeChatCompletionEventV1ObservabilityChatCompletionEventsEventIDLiveJudgingPostRequestTypedDict(
    TypedDict
):
    event_id: str
    judge_chat_completion_event_request: JudgeChatCompletionEventRequestTypedDict


class JudgeChatCompletionEventV1ObservabilityChatCompletionEventsEventIDLiveJudgingPostRequest(
    BaseModel
):
    event_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    judge_chat_completion_event_request: Annotated[
        JudgeChatCompletionEventRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
