"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3d1cd35fecc6

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteCampaignV1ObservabilityCampaignsCampaignIDDeleteRequestTypedDict(TypedDict):
    campaign_id: str


class DeleteCampaignV1ObservabilityCampaignsCampaignIDDeleteRequest(BaseModel):
    campaign_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
