"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f96acbcd45f7

from __future__ import annotations
from .feedresultchatcompletioneventpreview import (
    FeedResultChatCompletionEventPreview,
    FeedResultChatCompletionEventPreviewTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class SearchChatCompletionEventsResponseTypedDict(TypedDict):
    completion_events: FeedResultChatCompletionEventPreviewTypedDict


class SearchChatCompletionEventsResponse(BaseModel):
    completion_events: FeedResultChatCompletionEventPreview
