"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentchunk import ContentChunk, ContentChunkTypedDict
from mistralai.gcp.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.gcp.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


ToolMessageContentTypedDict = TypeAliasType(
    "ToolMessageContentTypedDict", Union[str, List[ContentChunkTypedDict]]
)


ToolMessageContent = TypeAliasType("ToolMessageContent", Union[str, List[ContentChunk]])


class ToolMessageTypedDict(TypedDict):
    content: Nullable[ToolMessageContentTypedDict]
    role: Literal["tool"]
    tool_call_id: NotRequired[Nullable[str]]
    name: NotRequired[Nullable[str]]


class ToolMessage(BaseModel):
    content: Nullable[ToolMessageContent]

    role: Annotated[
        Annotated[Literal["tool"], AfterValidator(validate_const("tool"))],
        pydantic.Field(alias="role"),
    ] = "tool"

    tool_call_id: OptionalNullable[str] = UNSET

    name: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["tool_call_id", "name"])
        nullable_fields = set(["content", "tool_call_id", "name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    ToolMessage.model_rebuild()
except NameError:
    pass
