"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 969acd9d6220

from __future__ import annotations
from .tempotraceresource import TempoTraceResource, TempoTraceResourceTypedDict
from .tempotracescopespan import TempoTraceScopeSpan, TempoTraceScopeSpanTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TempoTraceBatchTypedDict(TypedDict):
    resource: TempoTraceResourceTypedDict
    scope_spans: NotRequired[List[TempoTraceScopeSpanTypedDict]]
    r"""The spans of the scope"""


class TempoTraceBatch(BaseModel):
    resource: TempoTraceResource

    scope_spans: Annotated[
        Optional[List[TempoTraceScopeSpan]], pydantic.Field(alias="scopeSpans")
    ] = None
    r"""The spans of the scope"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["scopeSpans"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TempoTraceBatch.model_rebuild()
except NameError:
    pass
