"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 1b7d73eddf51

from __future__ import annotations
from .metadatadict import MetadataDict, MetadataDictTypedDict
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


AgentConversationAgentVersionTypedDict = TypeAliasType(
    "AgentConversationAgentVersionTypedDict", Union[str, int]
)


AgentConversationAgentVersion = TypeAliasType(
    "AgentConversationAgentVersion", Union[str, int]
)


class AgentConversationTypedDict(TypedDict):
    id: str
    created_at: datetime
    updated_at: datetime
    agent_id: str
    name: NotRequired[Nullable[str]]
    r"""Name given to the conversation."""
    description: NotRequired[Nullable[str]]
    r"""Description of the what the conversation is about."""
    metadata: NotRequired[Nullable[MetadataDictTypedDict]]
    r"""Custom metadata for the conversation."""
    object: Literal["conversation"]
    agent_version: NotRequired[Nullable[AgentConversationAgentVersionTypedDict]]


class AgentConversation(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    agent_id: str

    name: OptionalNullable[str] = UNSET
    r"""Name given to the conversation."""

    description: OptionalNullable[str] = UNSET
    r"""Description of the what the conversation is about."""

    metadata: OptionalNullable[MetadataDict] = UNSET
    r"""Custom metadata for the conversation."""

    object: Annotated[
        Annotated[
            Optional[Literal["conversation"]],
            AfterValidator(validate_const("conversation")),
        ],
        pydantic.Field(alias="object"),
    ] = "conversation"

    agent_version: OptionalNullable[AgentConversationAgentVersion] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["name", "description", "metadata", "object", "agent_version"]
        )
        nullable_fields = set(["name", "description", "metadata", "agent_version"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    AgentConversation.model_rebuild()
except NameError:
    pass
