"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b51ec296cc92

from __future__ import annotations
from typing import Literal


EncodingFormat = Literal[
    "float",
    "base64",
]
