"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b4d3fb07196e

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AuthDataTypedDict(TypedDict):
    client_id: str
    client_secret: str


class AuthData(BaseModel):
    client_id: str

    client_secret: str
