"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 9455e38a8c31

from __future__ import annotations
from .conversationpayload import ConversationPayload, ConversationPayloadTypedDict
from mistralai.client.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class CreateDatasetRecordRequestTypedDict(TypedDict):
    payload: ConversationPayloadTypedDict
    properties: Dict[str, Any]


class CreateDatasetRecordRequest(BaseModel):
    payload: ConversationPayload

    properties: Dict[str, Any]
