"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5bd25cdf9c7a

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Any, Dict, Union
from typing_extensions import TypeAliasType, TypedDict


RealtimeTranscriptionErrorDetailMessageTypedDict = TypeAliasType(
    "RealtimeTranscriptionErrorDetailMessageTypedDict", Union[str, Dict[str, Any]]
)
r"""Human-readable error message."""


RealtimeTranscriptionErrorDetailMessage = TypeAliasType(
    "RealtimeTranscriptionErrorDetailMessage", Union[str, Dict[str, Any]]
)
r"""Human-readable error message."""


class RealtimeTranscriptionErrorDetailTypedDict(TypedDict):
    message: RealtimeTranscriptionErrorDetailMessageTypedDict
    r"""Human-readable error message."""
    code: int
    r"""Internal error code for debugging."""


class RealtimeTranscriptionErrorDetail(BaseModel):
    message: RealtimeTranscriptionErrorDetailMessage
    r"""Human-readable error message."""

    code: int
    r"""Internal error code for debugging."""
