"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 1733e4765106

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


SSETypes = Union[
    Literal[
        "conversation.response.started",
        "conversation.response.done",
        "conversation.response.error",
        "message.output.delta",
        "tool.execution.started",
        "tool.execution.delta",
        "tool.execution.done",
        "agent.handoff.started",
        "agent.handoff.done",
        "function.call.delta",
    ],
    UnrecognizedStr,
]
r"""Server side events sent when streaming a conversation response."""
