"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 17e125b1022c

from __future__ import annotations
from .connector import Connector, ConnectorTypedDict
from .paginationresponse import PaginationResponse, PaginationResponseTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaginatedConnectorsTypedDict(TypedDict):
    items: List[ConnectorTypedDict]
    pagination: PaginationResponseTypedDict


class PaginatedConnectors(BaseModel):
    items: List[Connector]

    pagination: PaginationResponse
