"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a2b468c87a8a

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AuthURLResponseTypedDict(TypedDict):
    auth_url: str
    ttl: int


class AuthURLResponse(BaseModel):
    auth_url: str

    ttl: int
