"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 44727997dacb

from __future__ import annotations
from .agenthandoffentry import AgentHandoffEntry, AgentHandoffEntryTypedDict
from .functioncallentry import FunctionCallEntry, FunctionCallEntryTypedDict
from .functionresultentry import FunctionResultEntry, FunctionResultEntryTypedDict
from .messageinputentry import MessageInputEntry, MessageInputEntryTypedDict
from .messageoutputentry import MessageOutputEntry, MessageOutputEntryTypedDict
from .toolexecutionentry import ToolExecutionEntry, ToolExecutionEntryTypedDict
from typing import Union
from typing_extensions import TypeAliasType


InputEntriesTypedDict = TypeAliasType(
    "InputEntriesTypedDict",
    Union[
        FunctionResultEntryTypedDict,
        MessageInputEntryTypedDict,
        MessageOutputEntryTypedDict,
        AgentHandoffEntryTypedDict,
        ToolExecutionEntryTypedDict,
        FunctionCallEntryTypedDict,
    ],
)


InputEntries = TypeAliasType(
    "InputEntries",
    Union[
        FunctionResultEntry,
        MessageInputEntry,
        MessageOutputEntry,
        AgentHandoffEntry,
        ToolExecutionEntry,
        FunctionCallEntry,
    ],
)
