"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: dbb7fb36a4fd

from __future__ import annotations
from .failure import Failure, FailureTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowExecutionFailedAttributesTypedDict(TypedDict):
    r"""Attributes for workflow execution failed events."""

    task_id: str
    r"""Unique identifier for the task within the workflow execution."""
    failure: FailureTypedDict
    r"""Represents an error or exception that occurred during execution."""


class WorkflowExecutionFailedAttributes(BaseModel):
    r"""Attributes for workflow execution failed events."""

    task_id: str
    r"""Unique identifier for the task within the workflow execution."""

    failure: Failure
    r"""Represents an error or exception that occurred during execution."""
