"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0b1bd06b24af

from __future__ import annotations
from .fetchfieldoptioncountsrequest import (
    FetchFieldOptionCountsRequest,
    FetchFieldOptionCountsRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class GetChatCompletionFieldOptionsCountsV1ObservabilityChatCompletionFieldsFieldNameOptionsCountsPostRequestTypedDict(
    TypedDict
):
    field_name: str
    fetch_field_option_counts_request: FetchFieldOptionCountsRequestTypedDict


class GetChatCompletionFieldOptionsCountsV1ObservabilityChatCompletionFieldsFieldNameOptionsCountsPostRequest(
    BaseModel
):
    field_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    fetch_field_option_counts_request: Annotated[
        FetchFieldOptionCountsRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
