"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


ResponseFormats = Literal[
    "text",
    "json_object",
    "json_schema",
]
