"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8d809b14b144

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ImportDatasetFromPlaygroundRequestTypedDict(TypedDict):
    conversation_ids: List[str]


class ImportDatasetFromPlaygroundRequest(BaseModel):
    conversation_ids: List[str]
