"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 1f0b404ba621

from __future__ import annotations
from .deploymentresponse import DeploymentResponse, DeploymentResponseTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DeploymentListResponseTypedDict(TypedDict):
    deployments: List[DeploymentResponseTypedDict]
    r"""List of deployments"""


class DeploymentListResponse(BaseModel):
    deployments: List[DeploymentResponse]
    r"""List of deployments"""
