"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 16c54f54e60f

from __future__ import annotations
from .signalinvocationbody import SignalInvocationBody, SignalInvocationBodyTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SignalWorkflowExecutionV1WorkflowsExecutionsExecutionIDSignalsPostRequestTypedDict(
    TypedDict
):
    execution_id: str
    signal_invocation_body: SignalInvocationBodyTypedDict


class SignalWorkflowExecutionV1WorkflowsExecutionsExecutionIDSignalsPostRequest(
    BaseModel
):
    execution_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    signal_invocation_body: Annotated[
        SignalInvocationBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
