"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2699936a7546

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Dict
from typing_extensions import NotRequired, TypedDict


class TurbineToolLocaleTypedDict(TypedDict):
    name: NotRequired[Nullable[Dict[str, str]]]
    description: NotRequired[Nullable[Dict[str, str]]]
    usage_sentence: NotRequired[Nullable[Dict[str, str]]]
    working_description: NotRequired[Nullable[Dict[str, str]]]
    done_description: NotRequired[Nullable[Dict[str, str]]]


class TurbineToolLocale(BaseModel):
    name: OptionalNullable[Dict[str, str]] = UNSET

    description: OptionalNullable[Dict[str, str]] = UNSET

    usage_sentence: OptionalNullable[Dict[str, str]] = UNSET

    working_description: OptionalNullable[Dict[str, str]] = UNSET

    done_description: OptionalNullable[Dict[str, str]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "name",
                "description",
                "usage_sentence",
                "working_description",
                "done_description",
            ]
        )
        nullable_fields = set(
            [
                "name",
                "description",
                "usage_sentence",
                "working_description",
                "done_description",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
