"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3f07e1eb25f9

from __future__ import annotations
from typing import Literal


JudgeOutputType = Literal[
    "REGRESSION",
    "CLASSIFICATION",
]
