"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a2da1a3b8198

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class TempoTraceScopeTypedDict(TypedDict):
    name: str
    r"""The name of the span"""


class TempoTraceScope(BaseModel):
    name: str
    r"""The name of the span"""
