"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 84a8007518c7

from __future__ import annotations
from .instructrequest import InstructRequest, InstructRequestTypedDict
from typing import List, Union
from typing_extensions import TypeAliasType


InputsTypedDict = TypeAliasType(
    "InputsTypedDict", Union[InstructRequestTypedDict, List[InstructRequestTypedDict]]
)
r"""Chat to classify"""


Inputs = TypeAliasType("Inputs", Union[InstructRequest, List[InstructRequest]])
r"""Chat to classify"""
