"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6e93e5363630

from __future__ import annotations
from .importdatasetfromfilerequest import (
    ImportDatasetFromFileRequest,
    ImportDatasetFromFileRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostDatasetRecordsFromFileV1ObservabilityDatasetsDatasetIDImportsFromFilePostRequestTypedDict(
    TypedDict
):
    dataset_id: str
    import_dataset_from_file_request: ImportDatasetFromFileRequestTypedDict


class PostDatasetRecordsFromFileV1ObservabilityDatasetsDatasetIDImportsFromFilePostRequest(
    BaseModel
):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    import_dataset_from_file_request: Annotated[
        ImportDatasetFromFileRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
