"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 011c39501c26

from __future__ import annotations
from .messageentries import MessageEntries, MessageEntriesTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, TypedDict


class ConversationMessagesTypedDict(TypedDict):
    r"""Similar to the conversation history but only keep the messages"""

    conversation_id: str
    messages: List[MessageEntriesTypedDict]
    object: Literal["conversation.messages"]


class ConversationMessages(BaseModel):
    r"""Similar to the conversation history but only keep the messages"""

    conversation_id: str

    messages: List[MessageEntries]

    object: Annotated[
        Annotated[
            Optional[Literal["conversation.messages"]],
            AfterValidator(validate_const("conversation.messages")),
        ],
        pydantic.Field(alias="object"),
    ] = "conversation.messages"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ConversationMessages.model_rebuild()
except NameError:
    pass
