"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f70686df1fa5

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


EventType = Union[
    Literal[
        "EVENT",
        "EVENT_PROGRESS",
    ],
    UnrecognizedStr,
]
