"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 4d5aab2705a0

from __future__ import annotations
from .judge import Judge, JudgeTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PaginatedResultJudgePreviewTypedDict(TypedDict):
    count: int
    results: NotRequired[List[JudgeTypedDict]]
    next: NotRequired[Nullable[str]]
    previous: NotRequired[Nullable[str]]


class PaginatedResultJudgePreview(BaseModel):
    count: int

    results: Optional[List[Judge]] = None

    next: OptionalNullable[str] = UNSET

    previous: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["results", "next", "previous"])
        nullable_fields = set(["next", "previous"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
