"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0aebdaa43ceb

from __future__ import annotations
from .mirrorsource import MirrorSource, MirrorSourceTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class MirrorConfigTypedDict(TypedDict):
    r"""Configuration for mirroring behavior."""

    mirror_source: MirrorSourceTypedDict
    r"""Source information for mirrored requests."""


class MirrorConfig(BaseModel):
    r"""Configuration for mirroring behavior."""

    mirror_source: MirrorSource
    r"""Source information for mirrored requests."""
