"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0b9fb891f354

from __future__ import annotations
from .jsonpayloadresponse import JSONPayloadResponse, JSONPayloadResponseTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CustomTaskCompletedAttributesResponseTypedDict(TypedDict):
    r"""Attributes for custom task completed events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""
    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""
    payload: JSONPayloadResponseTypedDict
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """


class CustomTaskCompletedAttributesResponse(BaseModel):
    r"""Attributes for custom task completed events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""

    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""

    payload: JSONPayloadResponse
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """
