"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: df8f17cf3e07

from __future__ import annotations
from .builtinconnectors import BuiltInConnectors
from datetime import datetime
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


ToolExecutionDeltaEventNameTypedDict = TypeAliasType(
    "ToolExecutionDeltaEventNameTypedDict", Union[BuiltInConnectors, str]
)


ToolExecutionDeltaEventName = TypeAliasType(
    "ToolExecutionDeltaEventName", Union[BuiltInConnectors, str]
)


class ToolExecutionDeltaEventTypedDict(TypedDict):
    id: str
    name: ToolExecutionDeltaEventNameTypedDict
    arguments: str
    type: Literal["tool.execution.delta"]
    created_at: NotRequired[datetime]
    output_index: NotRequired[int]


class ToolExecutionDeltaEvent(BaseModel):
    id: str

    name: ToolExecutionDeltaEventName

    arguments: str

    type: Annotated[
        Annotated[
            Literal["tool.execution.delta"],
            AfterValidator(validate_const("tool.execution.delta")),
        ],
        pydantic.Field(alias="type"),
    ] = "tool.execution.delta"

    created_at: Optional[datetime] = None

    output_index: Optional[int] = 0

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["created_at", "output_index"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ToolExecutionDeltaEvent.model_rebuild()
except NameError:
    pass
