"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c20f7db9633c

from __future__ import annotations
from .basetaskstatus import BaseTaskStatus
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class DatasetImportTaskTypedDict(TypedDict):
    id: str
    created_at: datetime
    updated_at: datetime
    deleted_at: Nullable[datetime]
    creator_id: str
    dataset_id: str
    workspace_id: str
    status: BaseTaskStatus
    progress: NotRequired[Nullable[int]]
    message: NotRequired[Nullable[str]]


class DatasetImportTask(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    deleted_at: Nullable[datetime]

    creator_id: str

    dataset_id: str

    workspace_id: str

    status: BaseTaskStatus

    progress: OptionalNullable[int] = UNSET

    message: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["progress", "message"])
        nullable_fields = set(["deleted_at", "progress", "message"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
