"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0205512146e6

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ProcessStatus = Union[
    Literal[
        "self_managed",
        "missing_content",
        "noop",
        "done",
        "todo",
        "in_progress",
        "error",
        "waiting_for_capacity",
    ],
    UnrecognizedStr,
]
