"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6cfbee9c4ec7

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BatchExecutionBodyTypedDict(TypedDict):
    execution_ids: List[str]
    r"""List of execution IDs to process"""


class BatchExecutionBody(BaseModel):
    execution_ids: List[str]
    r"""List of execution IDs to process"""
