"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8ca679b2c39a

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class ChatTranscriptionEventTypedDict(TypedDict):
    audio_url: str
    model: str
    response_message: Dict[str, Any]


class ChatTranscriptionEvent(BaseModel):
    audio_url: str

    model: str

    response_message: Dict[str, Any]
