"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 60012b559aee

from __future__ import annotations
from .filterpayload import FilterPayload, FilterPayloadTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CreateCampaignRequestTypedDict(TypedDict):
    search_params: FilterPayloadTypedDict
    judge_id: str
    name: str
    description: str
    max_nb_events: int


class CreateCampaignRequest(BaseModel):
    search_params: FilterPayload

    judge_id: str

    name: str

    description: str

    max_nb_events: int
