"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c4462a05fb08

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ResponseFormats = Union[
    Literal[
        "text",
        "json_object",
        "json_schema",
    ],
    UnrecognizedStr,
]
