"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 9c9947e768d3

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1AgentsDeleteAliasRequestTypedDict(TypedDict):
    agent_id: str
    alias: str


class AgentsAPIV1AgentsDeleteAliasRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alias: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
