"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ea15ddd64402

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class DeploymentResponseTypedDict(TypedDict):
    id: str
    r"""Unique identifier of the deployment"""
    name: str
    r"""Deployment name"""
    is_active: bool
    r"""Whether at least one worker is currently live"""
    created_at: datetime
    r"""When the deployment was first registered"""
    updated_at: datetime
    r"""When the deployment was last updated"""


class DeploymentResponse(BaseModel):
    id: str
    r"""Unique identifier of the deployment"""

    name: str
    r"""Deployment name"""

    is_active: bool
    r"""Whether at least one worker is currently live"""

    created_at: datetime
    r"""When the deployment was first registered"""

    updated_at: datetime
    r"""When the deployment was last updated"""
