"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b74b57603a4c

from __future__ import annotations
from .basetaskstatus import BaseTaskStatus
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class FetchCampaignStatusResponseTypedDict(TypedDict):
    status: BaseTaskStatus


class FetchCampaignStatusResponse(BaseModel):
    status: BaseTaskStatus
