"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c72b74412547

from __future__ import annotations
from .moderationllmv1config import ModerationLlmv1Config, ModerationLlmv1ConfigTypedDict
from .moderationllmv2config import ModerationLlmv2Config, ModerationLlmv2ConfigTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GuardrailConfigTypedDict(TypedDict):
    block_on_error: NotRequired[bool]
    r"""If true, return HTTP 403 and block request in the event of a server-side error"""
    moderation_llm_v1: NotRequired[Nullable[ModerationLlmv1ConfigTypedDict]]
    moderation_llm_v2: NotRequired[Nullable[ModerationLlmv2ConfigTypedDict]]


class GuardrailConfig(BaseModel):
    block_on_error: Optional[bool] = False
    r"""If true, return HTTP 403 and block request in the event of a server-side error"""

    moderation_llm_v1: OptionalNullable[ModerationLlmv1Config] = UNSET

    moderation_llm_v2: OptionalNullable[ModerationLlmv2Config] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["block_on_error", "moderation_llm_v1", "moderation_llm_v2"]
        )
        nullable_fields = set(["moderation_llm_v1", "moderation_llm_v2"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
