"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cbe8c44aee50

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ToolType = Union[
    Literal[
        "rag",
        "image",
        "code",
        "event",
    ],
    UnrecognizedStr,
]
