"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 56a16810d5de

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


WorkflowExecutionStatus = Union[
    Literal[
        "RUNNING",
        "COMPLETED",
        "FAILED",
        "CANCELED",
        "TERMINATED",
        "CONTINUED_AS_NEW",
        "TIMED_OUT",
        "RETRYING_AFTER_ERROR",
    ],
    UnrecognizedStr,
]
