"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 1a530d3674d8

from __future__ import annotations
from .metric import Metric, MetricTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CheckpointTypedDict(TypedDict):
    metrics: MetricTypedDict
    r"""Metrics at the step number during the fine-tuning job. Use these metrics to assess if the training is going smoothly (loss should decrease, token accuracy should increase)."""
    step_number: int
    r"""The step number that the checkpoint was created at."""
    created_at: int
    r"""The UNIX timestamp (in seconds) for when the checkpoint was created."""


class Checkpoint(BaseModel):
    metrics: Metric
    r"""Metrics at the step number during the fine-tuning job. Use these metrics to assess if the training is going smoothly (loss should decrease, token accuracy should increase)."""

    step_number: int
    r"""The step number that the checkpoint was created at."""

    created_at: int
    r"""The UNIX timestamp (in seconds) for when the checkpoint was created."""
