"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 201353e45f89

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class FieldGroupTypedDict(TypedDict):
    name: str
    label: str


class FieldGroup(BaseModel):
    name: str

    label: str
