"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 95abc4ec799a

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


MistralPromptMode = Union[Literal["reasoning",], UnrecognizedStr]
r"""Available options to the prompt_mode argument on the chat completion endpoint.
Values represent high-level intent. Assignment to actual SPs is handled internally.
System prompt may include knowledge cutoff date, model capabilities, tone to use, safety guidelines, etc.
"""
