"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c530f2fc64d0

from __future__ import annotations
from .agentconversation import AgentConversation, AgentConversationTypedDict
from .modelconversation import ModelConversation, ModelConversationTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing import Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class AgentsAPIV1ConversationsGetRequestTypedDict(TypedDict):
    conversation_id: str
    r"""ID of the conversation from which we are fetching metadata."""


class AgentsAPIV1ConversationsGetRequest(BaseModel):
    conversation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""ID of the conversation from which we are fetching metadata."""


ResponseV1ConversationsGetTypedDict = TypeAliasType(
    "ResponseV1ConversationsGetTypedDict",
    Union[AgentConversationTypedDict, ModelConversationTypedDict],
)
r"""Successful Response"""


ResponseV1ConversationsGet = TypeAliasType(
    "ResponseV1ConversationsGet", Union[AgentConversation, ModelConversation]
)
r"""Successful Response"""
