"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.gcp.client.types import BaseModel
from mistralai.gcp.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class TextChunkTypedDict(TypedDict):
    text: str
    type: Literal["text"]


class TextChunk(BaseModel):
    text: str

    type: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"


try:
    TextChunk.model_rebuild()
except NameError:
    pass
