"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f55510f5ff82

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class APIKeyAuthTypedDict(TypedDict):
    value: str
    type: Literal["api-key"]


class APIKeyAuth(BaseModel):
    value: str

    type: Annotated[
        Annotated[Literal["api-key"], AfterValidator(validate_const("api-key"))],
        pydantic.Field(alias="type"),
    ] = "api-key"


try:
    APIKeyAuth.model_rebuild()
except NameError:
    pass
