"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5da876c66fc5

from __future__ import annotations
from .workflowexecutionrequest import (
    WorkflowExecutionRequest,
    WorkflowExecutionRequestTypedDict,
)
from .workflowexecutionresponse import (
    WorkflowExecutionResponse,
    WorkflowExecutionResponseTypedDict,
)
from .workflowexecutionsyncresponse import (
    WorkflowExecutionSyncResponse,
    WorkflowExecutionSyncResponseTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class ExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePostRequestTypedDict(
    TypedDict
):
    workflow_identifier: str
    workflow_execution_request: WorkflowExecutionRequestTypedDict


class ExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePostRequest(BaseModel):
    workflow_identifier: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    workflow_execution_request: Annotated[
        WorkflowExecutionRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


ResponseExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePostTypedDict = (
    TypeAliasType(
        "ResponseExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePostTypedDict",
        Union[
            WorkflowExecutionSyncResponseTypedDict, WorkflowExecutionResponseTypedDict
        ],
    )
)
r"""Successful Response"""


ResponseExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePost = TypeAliasType(
    "ResponseExecuteWorkflowV1WorkflowsWorkflowIdentifierExecutePost",
    Union[WorkflowExecutionSyncResponse, WorkflowExecutionResponse],
)
r"""Successful Response"""
