"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c77172c4a9f6

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowScheduleResponseTypedDict(TypedDict):
    schedule_id: str
    r"""The ID of the schedule"""


class WorkflowScheduleResponse(BaseModel):
    schedule_id: str
    r"""The ID of the schedule"""
