"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b2882fa57029

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ImportDatasetFromFileRequestTypedDict(TypedDict):
    file_id: str


class ImportDatasetFromFileRequest(BaseModel):
    file_id: str
