"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 13b97e8095c4

from __future__ import annotations
from .paginatedresultdatasetrecord import (
    PaginatedResultDatasetRecord,
    PaginatedResultDatasetRecordTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListDatasetRecordsResponseTypedDict(TypedDict):
    records: PaginatedResultDatasetRecordTypedDict


class ListDatasetRecordsResponse(BaseModel):
    records: PaginatedResultDatasetRecord
