"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 9ad9741f4975

from __future__ import annotations
from .documenturlchunk import DocumentURLChunk, DocumentURLChunkTypedDict
from .imageurlchunk import ImageURLChunk, ImageURLChunkTypedDict
from .textchunk import TextChunk, TextChunkTypedDict
from .thinkchunk import ThinkChunk, ThinkChunkTypedDict
from .toolfilechunk import ToolFileChunk, ToolFileChunkTypedDict
from .toolreferencechunk import ToolReferenceChunk, ToolReferenceChunkTypedDict
from typing import Union
from typing_extensions import TypeAliasType


OutputContentChunksTypedDict = TypeAliasType(
    "OutputContentChunksTypedDict",
    Union[
        TextChunkTypedDict,
        ImageURLChunkTypedDict,
        DocumentURLChunkTypedDict,
        ThinkChunkTypedDict,
        ToolFileChunkTypedDict,
        ToolReferenceChunkTypedDict,
    ],
)


OutputContentChunks = TypeAliasType(
    "OutputContentChunks",
    Union[
        TextChunk,
        ImageURLChunk,
        DocumentURLChunk,
        ThinkChunk,
        ToolFileChunk,
        ToolReferenceChunk,
    ],
)
