"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.azure.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


LocTypedDict = TypeAliasType("LocTypedDict", Union[str, int])


Loc = TypeAliasType("Loc", Union[str, int])


class ContextTypedDict(TypedDict):
    pass


class Context(BaseModel):
    pass


class ValidationErrorTypedDict(TypedDict):
    loc: List[LocTypedDict]
    msg: str
    type: str
    input: NotRequired[Any]
    ctx: NotRequired[ContextTypedDict]


class ValidationError(BaseModel):
    loc: List[Loc]

    msg: str

    type: str

    input: Optional[Any] = None

    ctx: Optional[Context] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["input", "ctx"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
