"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b76eee4fdf6a

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


SpeechStreamEventTypes = Union[
    Literal[
        "speech.audio.delta",
        "speech.audio.done",
    ],
    UnrecognizedStr,
]
