"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: fcee60a4ea0d

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


Source = Union[
    Literal[
        "upload",
        "repository",
        "mistral",
    ],
    UnrecognizedStr,
]
