"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: db389a8abc34

from __future__ import annotations
from .paginatedresultjudgepreview import (
    PaginatedResultJudgePreview,
    PaginatedResultJudgePreviewTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListJudgesResponseTypedDict(TypedDict):
    judges: PaginatedResultJudgePreviewTypedDict


class ListJudgesResponse(BaseModel):
    judges: PaginatedResultJudgePreview
