"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 132faad0549a

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ModerationObjectTypedDict(TypedDict):
    categories: NotRequired[Dict[str, bool]]
    r"""Moderation result thresholds"""
    category_scores: NotRequired[Dict[str, float]]
    r"""Moderation result"""


class ModerationObject(BaseModel):
    categories: Optional[Dict[str, bool]] = None
    r"""Moderation result thresholds"""

    category_scores: Optional[Dict[str, float]] = None
    r"""Moderation result"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["categories", "category_scores"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
