"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a0e2a7a16bf8

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ShareEnum = Union[
    Literal[
        "Viewer",
        "Editor",
    ],
    UnrecognizedStr,
]
