"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cffe114c7ac7

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from mistralai.client.batch_jobs import BatchJobs
from typing import Optional


class Batch(BaseSDK):
    jobs: BatchJobs

    def __init__(
        self, sdk_config: SDKConfiguration, parent_ref: Optional[object] = None
    ) -> None:
        BaseSDK.__init__(self, sdk_config, parent_ref=parent_ref)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.jobs = BatchJobs(self.sdk_configuration, parent_ref=self.parent_ref)
