"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 30bdd050feac

from __future__ import annotations
from .workflow import Workflow, WorkflowTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowUnarchiveResponseTypedDict(TypedDict):
    workflow: WorkflowTypedDict


class WorkflowUnarchiveResponse(BaseModel):
    workflow: Workflow
