"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6f71f6fbf4c5

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


TranscriptionStreamEventTypes = Union[
    Literal[
        "transcription.language",
        "transcription.segment",
        "transcription.text.delta",
        "transcription.done",
    ],
    UnrecognizedStr,
]
