"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a9309422fed7

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


SampleType = Union[
    Literal[
        "pretrain",
        "instruct",
        "batch_request",
        "batch_result",
        "batch_error",
    ],
    UnrecognizedStr,
]
