"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 1ddc53a46c74

from __future__ import annotations
from .createdatasetrecordrequest import (
    CreateDatasetRecordRequest,
    CreateDatasetRecordRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CreateDatasetRecordV1ObservabilityDatasetsDatasetIDRecordsPostRequestTypedDict(
    TypedDict
):
    dataset_id: str
    create_dataset_record_request: CreateDatasetRecordRequestTypedDict


class CreateDatasetRecordV1ObservabilityDatasetsDatasetIDRecordsPostRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    create_dataset_record_request: Annotated[
        CreateDatasetRecordRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
