"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 230f55a36ebf

from __future__ import annotations
from .workflowwithworkerstatus import (
    WorkflowWithWorkerStatus,
    WorkflowWithWorkerStatusTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowGetResponseTypedDict(TypedDict):
    workflow: WorkflowWithWorkerStatusTypedDict


class WorkflowGetResponse(BaseModel):
    workflow: WorkflowWithWorkerStatus
