"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 143f97683a02

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict
from typing_extensions import NotRequired, TypedDict


class UpdateDefinitionTypedDict(TypedDict):
    name: str
    r"""Name of the update"""
    input_schema: Dict[str, Any]
    r"""Input JSON schema of the update's model"""
    description: NotRequired[Nullable[str]]
    r"""Description of the update"""
    output_schema: NotRequired[Nullable[Dict[str, Any]]]
    r"""Output JSON schema of the update's model"""


class UpdateDefinition(BaseModel):
    name: str
    r"""Name of the update"""

    input_schema: Dict[str, Any]
    r"""Input JSON schema of the update's model"""

    description: OptionalNullable[str] = UNSET
    r"""Description of the update"""

    output_schema: OptionalNullable[Dict[str, Any]] = UNSET
    r"""Output JSON schema of the update's model"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "output_schema"])
        nullable_fields = set(["description", "output_schema"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
