"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cbf14670ee00

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class DatasetTypedDict(TypedDict):
    id: str
    created_at: datetime
    updated_at: datetime
    deleted_at: Nullable[datetime]
    name: str
    description: str
    owner_id: str
    workspace_id: str


class Dataset(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    deleted_at: Nullable[datetime]

    name: str

    description: str

    owner_id: str

    workspace_id: str

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
