"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2d276ce938dc

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


BuiltInConnectors = Union[
    Literal[
        "web_search",
        "web_search_premium",
        "code_interpreter",
        "image_generation",
        "document_library",
    ],
    UnrecognizedStr,
]
