"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7cc1c80335a9

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict(TypedDict):
    model_id: str
    r"""The ID of the model to unarchive."""


class JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest(BaseModel):
    model_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the model to unarchive."""
