"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 61e08cf5eea9

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


BatchJobStatus = Union[
    Literal[
        "QUEUED",
        "RUNNING",
        "SUCCESS",
        "FAILED",
        "TIMEOUT_EXCEEDED",
        "CANCELLATION_REQUESTED",
        "CANCELLED",
    ],
    UnrecognizedStr,
]
