"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .textchunk import TextChunk, TextChunkTypedDict
from .thinkchunk import ThinkChunk, ThinkChunkTypedDict
from pydantic import Field
from typing import Union
from typing_extensions import Annotated, TypeAliasType


SystemMessageContentChunksTypedDict = TypeAliasType(
    "SystemMessageContentChunksTypedDict",
    Union[TextChunkTypedDict, ThinkChunkTypedDict],
)


SystemMessageContentChunks = Annotated[
    Union[TextChunk, ThinkChunk], Field(discriminator="type")
]
