"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 167c3b8a104e

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class OAuth2TokenAuthTypedDict(TypedDict):
    value: str
    type: Literal["oauth2-token"]


class OAuth2TokenAuth(BaseModel):
    value: str

    type: Annotated[
        Annotated[
            Literal["oauth2-token"], AfterValidator(validate_const("oauth2-token"))
        ],
        pydantic.Field(alias="type"),
    ] = "oauth2-token"


try:
    OAuth2TokenAuth.model_rebuild()
except NameError:
    pass
