"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 05e097395df3

from __future__ import annotations
from typing import Literal


FineTuneableModelType = Literal[
    "completion",
    "classifier",
]
