"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 028a34b08f9c

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class LibraryTypedDict(TypedDict):
    id: str
    name: str
    created_at: datetime
    updated_at: datetime
    owner_id: Nullable[str]
    owner_type: str
    total_size: int
    nb_documents: int
    chunk_size: Nullable[int]
    emoji: NotRequired[Nullable[str]]
    description: NotRequired[Nullable[str]]
    generated_description: NotRequired[Nullable[str]]
    explicit_user_members_count: NotRequired[Nullable[int]]
    explicit_workspace_members_count: NotRequired[Nullable[int]]
    org_sharing_role: NotRequired[Nullable[str]]
    generated_name: NotRequired[Nullable[str]]
    r"""Generated Name"""


class Library(BaseModel):
    id: str

    name: str

    created_at: datetime

    updated_at: datetime

    owner_id: Nullable[str]

    owner_type: str

    total_size: int

    nb_documents: int

    chunk_size: Nullable[int]

    emoji: OptionalNullable[str] = UNSET

    description: OptionalNullable[str] = UNSET

    generated_description: OptionalNullable[str] = UNSET

    explicit_user_members_count: OptionalNullable[int] = UNSET

    explicit_workspace_members_count: OptionalNullable[int] = UNSET

    org_sharing_role: OptionalNullable[str] = UNSET

    generated_name: OptionalNullable[str] = UNSET
    r"""Generated Name"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "emoji",
                "description",
                "generated_description",
                "explicit_user_members_count",
                "explicit_workspace_members_count",
                "org_sharing_role",
                "generated_name",
            ]
        )
        nullable_fields = set(
            [
                "owner_id",
                "chunk_size",
                "emoji",
                "description",
                "generated_description",
                "explicit_user_members_count",
                "explicit_workspace_members_count",
                "org_sharing_role",
                "generated_name",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
