"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c4659ad7a2a5

from __future__ import annotations
from mistralai.client.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TempoTraceAttributeIntValueTypedDict(TypedDict):
    int_value: str
    r"""The integer value of the attribute"""


class TempoTraceAttributeIntValue(BaseModel):
    int_value: Annotated[str, pydantic.Field(alias="intValue")]
    r"""The integer value of the attribute"""


try:
    TempoTraceAttributeIntValue.model_rebuild()
except NameError:
    pass
