"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ae8eb1017da6

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


ScalarMetricValueTypedDict = TypeAliasType(
    "ScalarMetricValueTypedDict", Union[int, float]
)


ScalarMetricValue = TypeAliasType("ScalarMetricValue", Union[int, float])


class ScalarMetricTypedDict(TypedDict):
    r"""Scalar metric with a single value."""

    value: ScalarMetricValueTypedDict


class ScalarMetric(BaseModel):
    r"""Scalar metric with a single value."""

    value: ScalarMetricValue
