"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cb248e9c0a00

from __future__ import annotations
from .tempotracescope import TempoTraceScope, TempoTraceScopeTypedDict
from .tempotracespan import TempoTraceSpan, TempoTraceSpanTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TempoTraceScopeSpanTypedDict(TypedDict):
    scope: TempoTraceScopeTypedDict
    spans: NotRequired[List[TempoTraceSpanTypedDict]]
    r"""The spans of the scope"""


class TempoTraceScopeSpan(BaseModel):
    scope: TempoTraceScope

    spans: Optional[List[TempoTraceSpan]] = None
    r"""The spans of the scope"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["spans"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
