"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b0af26e00bfa

from __future__ import annotations
from .updatedatasetrecordpropertiesrequest import (
    UpdateDatasetRecordPropertiesRequest,
    UpdateDatasetRecordPropertiesRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateDatasetRecordPropertiesV1ObservabilityDatasetRecordsDatasetRecordIDPropertiesPutRequestTypedDict(
    TypedDict
):
    dataset_record_id: str
    update_dataset_record_properties_request: (
        UpdateDatasetRecordPropertiesRequestTypedDict
    )


class UpdateDatasetRecordPropertiesV1ObservabilityDatasetRecordsDatasetRecordIDPropertiesPutRequest(
    BaseModel
):
    dataset_record_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_dataset_record_properties_request: Annotated[
        UpdateDatasetRecordPropertiesRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
