"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2b937728c88b

from __future__ import annotations
from .workflow import Workflow, WorkflowTypedDict
from .workflowcodedefinition import (
    WorkflowCodeDefinition,
    WorkflowCodeDefinitionTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WorkflowRegistrationTypedDict(TypedDict):
    id: str
    r"""Unique identifier of the workflow registration"""
    task_queue: str
    r"""Project name of the workflow"""
    definition: WorkflowCodeDefinitionTypedDict
    workflow_id: str
    r"""Workflow ID of the workflow"""
    workflow: NotRequired[Nullable[WorkflowTypedDict]]
    r"""Workflow of the workflow registration"""
    compatible_with_chat_assistant: NotRequired[bool]
    r"""Whether the workflow is compatible with chat assistant"""


class WorkflowRegistration(BaseModel):
    id: str
    r"""Unique identifier of the workflow registration"""

    task_queue: str
    r"""Project name of the workflow"""

    definition: WorkflowCodeDefinition

    workflow_id: str
    r"""Workflow ID of the workflow"""

    workflow: OptionalNullable[Workflow] = UNSET
    r"""Workflow of the workflow registration"""

    compatible_with_chat_assistant: Optional[bool] = False
    r"""Whether the workflow is compatible with chat assistant"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["workflow", "compatible_with_chat_assistant"])
        nullable_fields = set(["workflow"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
