"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c537bd5a9dd1

from __future__ import annotations
from .workflowupdaterequest import WorkflowUpdateRequest, WorkflowUpdateRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateWorkflowV1WorkflowsWorkflowIdentifierPutRequestTypedDict(TypedDict):
    workflow_identifier: str
    workflow_update_request: WorkflowUpdateRequestTypedDict


class UpdateWorkflowV1WorkflowsWorkflowIdentifierPutRequest(BaseModel):
    workflow_identifier: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    workflow_update_request: Annotated[
        WorkflowUpdateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
