"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c457ead40a69

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class UpdateDatasetRecordPropertiesRequestTypedDict(TypedDict):
    properties: Dict[str, Any]


class UpdateDatasetRecordPropertiesRequest(BaseModel):
    properties: Dict[str, Any]
