"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 22cc29d258db

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ExportDatasetResponseTypedDict(TypedDict):
    file_url: str


class ExportDatasetResponse(BaseModel):
    file_url: str
