"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .mistralgcperror import MistralGCPError
from typing import Any, TYPE_CHECKING

from mistralai.gcp.client.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
    from .no_response_error import NoResponseError
    from .responsevalidationerror import ResponseValidationError
    from .sdkerror import SDKError

__all__ = [
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "MistralGCPError",
    "NoResponseError",
    "ResponseValidationError",
    "SDKError",
]

_dynamic_imports: dict[str, str] = {
    "HTTPValidationError": ".httpvalidationerror",
    "HTTPValidationErrorData": ".httpvalidationerror",
    "NoResponseError": ".no_response_error",
    "ResponseValidationError": ".responsevalidationerror",
    "SDKError": ".sdkerror",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
