"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ef77c54a11b5

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class WorkflowExecutionSyncResponseTypedDict(TypedDict):
    r"""Response model for synchronous workflow execution"""

    workflow_name: str
    r"""Name of the workflow that was executed"""
    execution_id: str
    r"""ID of the workflow execution"""
    result: Any
    r"""The result of the workflow execution"""


class WorkflowExecutionSyncResponse(BaseModel):
    r"""Response model for synchronous workflow execution"""

    workflow_name: str
    r"""Name of the workflow that was executed"""

    execution_id: str
    r"""ID of the workflow execution"""

    result: Any
    r"""The result of the workflow execution"""
