"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: afd9cdc71834

from __future__ import annotations
from .inputs import Inputs, InputsTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ChatClassificationRequestTypedDict(TypedDict):
    model: str
    input: InputsTypedDict
    r"""Chat to classify"""


class ChatClassificationRequest(BaseModel):
    model: str

    input: Inputs
    r"""Chat to classify"""
