"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3ba234e5a8fc

from __future__ import annotations
from .conversationrestartrequest import (
    ConversationRestartRequest,
    ConversationRestartRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1ConversationsRestartRequestTypedDict(TypedDict):
    conversation_id: str
    r"""ID of the original conversation which is being restarted."""
    conversation_restart_request: ConversationRestartRequestTypedDict


class AgentsAPIV1ConversationsRestartRequest(BaseModel):
    conversation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""ID of the original conversation which is being restarted."""

    conversation_restart_request: Annotated[
        ConversationRestartRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
