"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ff33698df363

from __future__ import annotations
from .failure import Failure, FailureTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CustomTaskFailedAttributesTypedDict(TypedDict):
    r"""Attributes for custom task failed events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""
    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""
    failure: FailureTypedDict
    r"""Represents an error or exception that occurred during execution."""


class CustomTaskFailedAttributes(BaseModel):
    r"""Attributes for custom task failed events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""

    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""

    failure: Failure
    r"""Represents an error or exception that occurred during execution."""
