"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 30281fcedce6

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class QueryWorkflowResponseTypedDict(TypedDict):
    query_name: str
    result: Any
    r"""The result of the Query workflow call"""


class QueryWorkflowResponse(BaseModel):
    query_name: str

    result: Any
    r"""The result of the Query workflow call"""
