"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b8558eff0be0

from __future__ import annotations
from .networkencodedinput import NetworkEncodedInput, NetworkEncodedInputTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


UpdateInvocationBodyInputTypedDict = TypeAliasType(
    "UpdateInvocationBodyInputTypedDict",
    Union[NetworkEncodedInputTypedDict, Dict[str, Any]],
)
r"""Input data for the update, matching its schema"""


UpdateInvocationBodyInput = TypeAliasType(
    "UpdateInvocationBodyInput", Union[NetworkEncodedInput, Dict[str, Any]]
)
r"""Input data for the update, matching its schema"""


class UpdateInvocationBodyTypedDict(TypedDict):
    name: str
    r"""The name of the update to request"""
    input: NotRequired[Nullable[UpdateInvocationBodyInputTypedDict]]
    r"""Input data for the update, matching its schema"""


class UpdateInvocationBody(BaseModel):
    name: str
    r"""The name of the update to request"""

    input: OptionalNullable[UpdateInvocationBodyInput] = UNSET
    r"""Input data for the update, matching its schema"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["input"])
        nullable_fields = set(["input"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
