"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 9ad8915328dd

from __future__ import annotations
from .createjudgerequest import CreateJudgeRequest, CreateJudgeRequestTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class JudgeDatasetRecordRequestTypedDict(TypedDict):
    judge_definition: CreateJudgeRequestTypedDict


class JudgeDatasetRecordRequest(BaseModel):
    judge_definition: CreateJudgeRequest
