"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 297e8905d5af

from __future__ import annotations
from .textchunk import TextChunk, TextChunkTypedDict
from .thinkchunk import ThinkChunk, ThinkChunkTypedDict
from mistralai.client.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import Union
from typing_extensions import Annotated, TypeAliasType


SystemMessageContentChunksTypedDict = TypeAliasType(
    "SystemMessageContentChunksTypedDict",
    Union[TextChunkTypedDict, ThinkChunkTypedDict],
)


SystemMessageContentChunks = Annotated[
    Union[Annotated[TextChunk, Tag("text")], Annotated[ThinkChunk, Tag("thinking")]],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]
