"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 9aaa9eecac09

from __future__ import annotations
from .failure import Failure, FailureTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ActivityTaskRetryingAttributesTypedDict(TypedDict):
    r"""Attributes for activity task retrying events."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""
    activity_name: str
    r"""The registered name of the activity being executed."""
    attempt: int
    r"""The attempt number that failed (1-indexed)."""
    failure: FailureTypedDict
    r"""Represents an error or exception that occurred during execution."""


class ActivityTaskRetryingAttributes(BaseModel):
    r"""Attributes for activity task retrying events."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""

    activity_name: str
    r"""The registered name of the activity being executed."""

    attempt: int
    r"""The attempt number that failed (1-indexed)."""

    failure: Failure
    r"""Represents an error or exception that occurred during execution."""
