"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6dc5321dbe77

from __future__ import annotations
from .encodedpayloadoptions import EncodedPayloadOptions
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class NetworkEncodedInputTypedDict(TypedDict):
    b64payload: str
    r"""The encoded payload"""
    encoding_options: NotRequired[List[EncodedPayloadOptions]]
    r"""The encoding of the payload"""
    empty: NotRequired[bool]
    r"""Whether the payload is empty"""


class NetworkEncodedInput(BaseModel):
    b64payload: str
    r"""The encoded payload"""

    encoding_options: Optional[List[EncodedPayloadOptions]] = None
    r"""The encoding of the payload"""

    empty: Optional[bool] = False
    r"""Whether the payload is empty"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["encoding_options", "empty"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
