"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .completionresponsestreamchoice import (
    CompletionResponseStreamChoice,
    CompletionResponseStreamChoiceTypedDict,
)
from .usageinfo import UsageInfo, UsageInfoTypedDict
from mistralai.gcp.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CompletionChunkTypedDict(TypedDict):
    id: str
    model: str
    choices: List[CompletionResponseStreamChoiceTypedDict]
    object: NotRequired[str]
    created: NotRequired[int]
    usage: NotRequired[UsageInfoTypedDict]


class CompletionChunk(BaseModel):
    id: str

    model: str

    choices: List[CompletionResponseStreamChoice]

    object: Optional[str] = None

    created: Optional[int] = None

    usage: Optional[UsageInfo] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object", "created", "usage"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
