"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 307695cde5c2

from __future__ import annotations
from .paginatedresultcampaignpreview import (
    PaginatedResultCampaignPreview,
    PaginatedResultCampaignPreviewTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListCampaignsResponseTypedDict(TypedDict):
    campaigns: PaginatedResultCampaignPreviewTypedDict


class ListCampaignsResponse(BaseModel):
    campaigns: PaginatedResultCampaignPreview
