"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: df4b1182d193

from __future__ import annotations
from .voiceresponse import VoiceResponse, VoiceResponseTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class VoiceListResponseTypedDict(TypedDict):
    r"""Schema for voice list response"""

    items: List[VoiceResponseTypedDict]
    total: int
    page: int
    page_size: int
    total_pages: int


class VoiceListResponse(BaseModel):
    r"""Schema for voice list response"""

    items: List[VoiceResponse]

    total: int

    page: int

    page_size: int

    total_pages: int
