"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e18de4849423

from __future__ import annotations
from .paginatedresultdatasetpreview import (
    PaginatedResultDatasetPreview,
    PaginatedResultDatasetPreviewTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListDatasetsResponseTypedDict(TypedDict):
    datasets: PaginatedResultDatasetPreviewTypedDict


class ListDatasetsResponse(BaseModel):
    datasets: PaginatedResultDatasetPreview
