"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f635c1a3d02b

from __future__ import annotations
from .paginatedresultdatasetimporttask import (
    PaginatedResultDatasetImportTask,
    PaginatedResultDatasetImportTaskTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListDatasetImportTasksResponseTypedDict(TypedDict):
    tasks: PaginatedResultDatasetImportTaskTypedDict


class ListDatasetImportTasksResponse(BaseModel):
    tasks: PaginatedResultDatasetImportTask
