"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c7c383a6c05f

from __future__ import annotations
from mistralai.client.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TempoTraceAttributeBoolValueTypedDict(TypedDict):
    bool_value: bool
    r"""The boolean value of the attribute"""


class TempoTraceAttributeBoolValue(BaseModel):
    bool_value: Annotated[bool, pydantic.Field(alias="boolValue")]
    r"""The boolean value of the attribute"""


try:
    TempoTraceAttributeBoolValue.model_rebuild()
except NameError:
    pass
