"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2445f12b2a57

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class ClassificationTargetResultTypedDict(TypedDict):
    scores: Dict[str, float]


class ClassificationTargetResult(BaseModel):
    scores: Dict[str, float]
