"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 399da05bd75e

from __future__ import annotations
from .voiceupdaterequest import VoiceUpdateRequest, VoiceUpdateRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateVoiceV1AudioVoicesVoiceIDPatchRequestTypedDict(TypedDict):
    voice_id: str
    voice_update_request: VoiceUpdateRequestTypedDict


class UpdateVoiceV1AudioVoicesVoiceIDPatchRequest(BaseModel):
    voice_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    voice_update_request: Annotated[
        VoiceUpdateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
