"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 046a094d3ef9

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CreateDatasetRequestTypedDict(TypedDict):
    name: str
    description: str


class CreateDatasetRequest(BaseModel):
    name: str

    description: str
