"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8b926028b7b2

from __future__ import annotations
from typing import Literal


EventSource = Literal[
    "DATABASE",
    "LIVE",
]
