"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3fae92e2573a

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetDeploymentV1WorkflowsDeploymentsNameGetRequestTypedDict(TypedDict):
    name: str


class GetDeploymentV1WorkflowsDeploymentsNameGetRequest(BaseModel):
    name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
