"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: bb55993c932d

from __future__ import annotations
from .updateagentrequest import UpdateAgentRequest, UpdateAgentRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1AgentsUpdateRequestTypedDict(TypedDict):
    agent_id: str
    update_agent_request: UpdateAgentRequestTypedDict


class AgentsAPIV1AgentsUpdateRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_agent_request: Annotated[
        UpdateAgentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
