"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6b388bc155dd

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class MessageResponseTypedDict(TypedDict):
    message: str


class MessageResponse(BaseModel):
    message: str
