"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 40c697c1e617

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


TempoTraceScopeKind = Union[
    Literal[
        "SPAN_KIND_INTERNAL",
        "SPAN_KIND_SERVER",
        "SPAN_KIND_CLIENT",
    ],
    UnrecognizedStr,
]
