"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ae572b470a30

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ObservabilityErrorCode = Union[
    Literal[
        "UNKNOWN_ERROR",
        "VALIDATION_ERROR",
        "AUTH_FORBIDDEN",
        "AUTH_FORBIDDEN_NOT_WORKSPACE_ADMIN",
        "AUTH_FORBIDDEN_WORKSPACE_NOT_FOUND",
        "AUTH_FORBIDDEN_ROLE_NOT_FOUND",
        "AUTH_FORBIDDEN_ORG_NOT_WHITELISTED",
        "AUTH_UNAUTHORIZED",
        "FEATURE_NOT_SUPPORTED",
        "FIELDS_BAD_REQUEST",
        "FIELDS_NOT_FOUND",
        "SEARCH_NOT_FOUND",
        "SEARCH_BAD_REQUEST",
        "SEARCH_SERVICE_UNAVAILABLE",
        "DATABASE_ERROR",
        "DATABASE_TIMEOUT",
        "DATABASE_UNAVAILABLE",
        "DATABASE_QUERY_ERROR",
        "SEARCH_FILTER_TO_SQL_CONVERSION_ERROR",
        "JUDGE_CONVERSATION_FORMAT_ERROR",
        "JUDGE_MISTRAL_API_ERROR",
        "JUDGE_MISTRAL_API_TIMEOUT",
        "JUDGE_NAME_ALREADY_EXISTS",
        "JUDGE_NOT_FOUND",
        "JUDGE_ALREADY_HAS_NEW_VERSION",
        "JUDGE_USED_IN_CAMPAIGN_CANNOT_BE_UPDATED",
        "JUDGE_DID_NOT_CHANGE",
        "CAMPAIGN_NOT_FOUND",
        "CAMPAIGN_NO_MATCHING_EVENTS",
        "DATASET_NOT_FOUND",
        "DATASET_TASK_NOT_FOUND",
        "DATASET_RECORD_NOT_FOUND",
        "DATASET_RECORD_FORMAT_ERROR",
        "AGENT_NOT_FOUND",
        "AGENT_MISTRAL_API_ERROR",
        "EVALUATION_NOT_FOUND",
        "EVALUATION_CURRENTLY_RUNNING",
        "EVALUATION_RECORD_NOT_FOUND",
        "EVALUATION_RUN_NOT_FOUND",
        "EVALUATION_RUN_TRANSITION_IS_INVALID",
        "EVALUATION_RUN_TRANSITION_IS_RUNNING_ALREADY",
        "EVALUATION_RUN_TRANSITION_ERROR",
        "TEMPLATE_SYNTAX_ERROR",
    ],
    UnrecognizedStr,
]
