"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b4aeeb03b57a

from __future__ import annotations
from typing import Literal


WorkflowEventType = Literal[
    "WORKFLOW_EXECUTION_STARTED",
    "WORKFLOW_EXECUTION_COMPLETED",
    "WORKFLOW_EXECUTION_FAILED",
    "WORKFLOW_EXECUTION_CANCELED",
    "WORKFLOW_EXECUTION_CONTINUED_AS_NEW",
    "WORKFLOW_TASK_TIMED_OUT",
    "WORKFLOW_TASK_FAILED",
    "CUSTOM_TASK_STARTED",
    "CUSTOM_TASK_IN_PROGRESS",
    "CUSTOM_TASK_COMPLETED",
    "CUSTOM_TASK_FAILED",
    "CUSTOM_TASK_TIMED_OUT",
    "CUSTOM_TASK_CANCELED",
    "ACTIVITY_TASK_STARTED",
    "ACTIVITY_TASK_COMPLETED",
    "ACTIVITY_TASK_RETRYING",
    "ACTIVITY_TASK_FAILED",
]
