"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: fa5d55a9d6cf

from __future__ import annotations
from .updatedatasetrecordpayloadrequest import (
    UpdateDatasetRecordPayloadRequest,
    UpdateDatasetRecordPayloadRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateDatasetRecordPayloadV1ObservabilityDatasetRecordsDatasetRecordIDPayloadPutRequestTypedDict(
    TypedDict
):
    dataset_record_id: str
    update_dataset_record_payload_request: UpdateDatasetRecordPayloadRequestTypedDict


class UpdateDatasetRecordPayloadV1ObservabilityDatasetRecordsDatasetRecordIDPayloadPutRequest(
    BaseModel
):
    dataset_record_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_dataset_record_payload_request: Annotated[
        UpdateDatasetRecordPayloadRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
