"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3899a98a55dd

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AgentAliasResponseTypedDict(TypedDict):
    alias: str
    version: int
    created_at: datetime
    updated_at: datetime


class AgentAliasResponse(BaseModel):
    alias: str

    version: int

    created_at: datetime

    updated_at: datetime
