"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 247ebe411537

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class ConnectorToolLocaleTypedDict(TypedDict):
    name: Dict[str, str]
    description: Dict[str, str]
    usage_sentence: Dict[str, str]


class ConnectorToolLocale(BaseModel):
    name: Dict[str, str]

    description: Dict[str, str]

    usage_sentence: Dict[str, str]
