"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 4c2a8ff4d52b

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class ModerationLlmv2CategoryThresholdsTypedDict(TypedDict):
    sexual: NotRequired[Nullable[float]]
    hate_and_discrimination: NotRequired[Nullable[float]]
    violence_and_threats: NotRequired[Nullable[float]]
    dangerous: NotRequired[Nullable[float]]
    criminal: NotRequired[Nullable[float]]
    selfharm: NotRequired[Nullable[float]]
    health: NotRequired[Nullable[float]]
    financial: NotRequired[Nullable[float]]
    law: NotRequired[Nullable[float]]
    pii: NotRequired[Nullable[float]]
    jailbreaking: NotRequired[Nullable[float]]


class ModerationLlmv2CategoryThresholds(BaseModel):
    sexual: OptionalNullable[float] = UNSET

    hate_and_discrimination: OptionalNullable[float] = UNSET

    violence_and_threats: OptionalNullable[float] = UNSET

    dangerous: OptionalNullable[float] = UNSET

    criminal: OptionalNullable[float] = UNSET

    selfharm: OptionalNullable[float] = UNSET

    health: OptionalNullable[float] = UNSET

    financial: OptionalNullable[float] = UNSET

    law: OptionalNullable[float] = UNSET

    pii: OptionalNullable[float] = UNSET

    jailbreaking: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "sexual",
                "hate_and_discrimination",
                "violence_and_threats",
                "dangerous",
                "criminal",
                "selfharm",
                "health",
                "financial",
                "law",
                "pii",
                "jailbreaking",
            ]
        )
        nullable_fields = set(
            [
                "sexual",
                "hate_and_discrimination",
                "violence_and_threats",
                "dangerous",
                "criminal",
                "selfharm",
                "health",
                "financial",
                "law",
                "pii",
                "jailbreaking",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
