"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 4823c1e80942

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class WandbIntegrationTypedDict(TypedDict):
    project: str
    r"""The name of the project that the new run will be created under."""
    api_key: str
    r"""The WandB API key to use for authentication."""
    type: Literal["wandb"]
    name: NotRequired[Nullable[str]]
    r"""A display name to set for the run. If not set, will use the job ID as the name."""
    run_name: NotRequired[Nullable[str]]


class WandbIntegration(BaseModel):
    project: str
    r"""The name of the project that the new run will be created under."""

    api_key: str
    r"""The WandB API key to use for authentication."""

    type: Annotated[
        Annotated[Literal["wandb"], AfterValidator(validate_const("wandb"))],
        pydantic.Field(alias="type"),
    ] = "wandb"

    name: OptionalNullable[str] = UNSET
    r"""A display name to set for the run. If not set, will use the job ID as the name."""

    run_name: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["name", "run_name"])
        nullable_fields = set(["name", "run_name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    WandbIntegration.model_rebuild()
except NameError:
    pass
