"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 48623263df72

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


EventProgressStatus = Union[
    Literal[
        "RUNNING",
        "COMPLETED",
        "FAILED",
    ],
    UnrecognizedStr,
]
