"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f08c10d149f5

from __future__ import annotations
from .finetunedmodelcapabilities import (
    FineTunedModelCapabilities,
    FineTunedModelCapabilitiesTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CompletionFineTunedModelTypedDict(TypedDict):
    id: str
    created: int
    owned_by: str
    workspace_id: str
    root: str
    root_version: str
    archived: bool
    capabilities: FineTunedModelCapabilitiesTypedDict
    object: Literal["model"]
    name: NotRequired[Nullable[str]]
    description: NotRequired[Nullable[str]]
    max_context_length: NotRequired[int]
    aliases: NotRequired[List[str]]
    job: NotRequired[Nullable[str]]
    model_type: Literal["completion"]


class CompletionFineTunedModel(BaseModel):
    id: str

    created: int

    owned_by: str

    workspace_id: str

    root: str

    root_version: str

    archived: bool

    capabilities: FineTunedModelCapabilities

    object: Annotated[
        Annotated[Optional[Literal["model"]], AfterValidator(validate_const("model"))],
        pydantic.Field(alias="object"),
    ] = "model"

    name: OptionalNullable[str] = UNSET

    description: OptionalNullable[str] = UNSET

    max_context_length: Optional[int] = 32768

    aliases: Optional[List[str]] = None

    job: OptionalNullable[str] = UNSET

    model_type: Annotated[
        Annotated[Literal["completion"], AfterValidator(validate_const("completion"))],
        pydantic.Field(alias="model_type"),
    ] = "completion"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["object", "name", "description", "max_context_length", "aliases", "job"]
        )
        nullable_fields = set(["name", "description", "job"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    CompletionFineTunedModel.model_rebuild()
except NameError:
    pass
