"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f593d8e66833

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .paginationinfo import PaginationInfo, PaginationInfoTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListDocumentsResponseTypedDict(TypedDict):
    pagination: PaginationInfoTypedDict
    data: List[DocumentTypedDict]


class ListDocumentsResponse(BaseModel):
    pagination: PaginationInfo

    data: List[Document]
