"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ee475b85bfc7

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ImportDatasetFromCampaignRequestTypedDict(TypedDict):
    campaign_id: str


class ImportDatasetFromCampaignRequest(BaseModel):
    campaign_id: str
