"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f2e953cfb4fe

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


Confirmation = Literal[
    "allow",
    "deny",
]


class ToolCallConfirmationTypedDict(TypedDict):
    tool_call_id: str
    confirmation: Confirmation


class ToolCallConfirmation(BaseModel):
    tool_call_id: str

    confirmation: Confirmation
