"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8e28cb9aff1a

from __future__ import annotations
from .paginatedresultchatcompletioneventpreview import (
    PaginatedResultChatCompletionEventPreview,
    PaginatedResultChatCompletionEventPreviewTypedDict,
)
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ListCampaignSelectedEventsResponseTypedDict(TypedDict):
    completion_events: PaginatedResultChatCompletionEventPreviewTypedDict


class ListCampaignSelectedEventsResponse(BaseModel):
    completion_events: PaginatedResultChatCompletionEventPreview
