"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: df556a618365

from __future__ import annotations
from .library import Library, LibraryTypedDict
from .paginationinfo import PaginationInfo, PaginationInfoTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListLibrariesResponseTypedDict(TypedDict):
    pagination: PaginationInfoTypedDict
    data: List[LibraryTypedDict]


class ListLibrariesResponse(BaseModel):
    pagination: PaginationInfo

    data: List[Library]
