"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ffa42818fea3

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from pydantic import model_serializer
from typing import List, Literal, Union
from typing_extensions import NotRequired, TypedDict


BaseFieldDefinitionType = Union[
    Literal[
        "ENUM",
        "TEXT",
        "INT",
        "FLOAT",
        "BOOL",
        "TIMESTAMP",
        "ARRAY",
    ],
    UnrecognizedStr,
]


SupportedOperator = Union[
    Literal[
        "lt",
        "lte",
        "gt",
        "gte",
        "startswith",
        "istartswith",
        "endswith",
        "iendswith",
        "contains",
        "icontains",
        "matches",
        "notcontains",
        "inotcontains",
        "eq",
        "neq",
        "isnull",
        "includes",
        "excludes",
        "len_eq",
    ],
    UnrecognizedStr,
]


class BaseFieldDefinitionTypedDict(TypedDict):
    name: str
    label: str
    type: BaseFieldDefinitionType
    supported_operators: List[SupportedOperator]
    group: NotRequired[Nullable[str]]


class BaseFieldDefinition(BaseModel):
    name: str

    label: str

    type: BaseFieldDefinitionType

    supported_operators: List[SupportedOperator]

    group: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["group"])
        nullable_fields = set(["group"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
