"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 00b34ce0a24d

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


APIEndpoint = Union[
    Literal[
        "/v1/chat/completions",
        "/v1/embeddings",
        "/v1/fim/completions",
        "/v1/moderations",
        "/v1/chat/moderations",
        "/v1/ocr",
        "/v1/classifications",
        "/v1/chat/classifications",
        "/v1/conversations",
        "/v1/audio/transcriptions",
    ],
    UnrecognizedStr,
]
