"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ocrimageobject import OCRImageObject, OCRImageObjectTypedDict
from .ocrpagedimensions import OCRPageDimensions, OCRPageDimensionsTypedDict
from .ocrtableobject import OCRTableObject, OCRTableObjectTypedDict
from mistralai.azure.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OCRPageObjectTypedDict(TypedDict):
    index: int
    r"""The page index in a pdf document starting from 0"""
    markdown: str
    r"""The markdown string response of the page"""
    images: List[OCRImageObjectTypedDict]
    r"""List of all extracted images in the page"""
    dimensions: Nullable[OCRPageDimensionsTypedDict]
    r"""The dimensions of the PDF Page's screenshot image"""
    tables: NotRequired[List[OCRTableObjectTypedDict]]
    r"""List of all extracted tables in the page"""
    hyperlinks: NotRequired[List[str]]
    r"""List of all hyperlinks in the page"""
    header: NotRequired[Nullable[str]]
    r"""Header of the page"""
    footer: NotRequired[Nullable[str]]
    r"""Footer of the page"""


class OCRPageObject(BaseModel):
    index: int
    r"""The page index in a pdf document starting from 0"""

    markdown: str
    r"""The markdown string response of the page"""

    images: List[OCRImageObject]
    r"""List of all extracted images in the page"""

    dimensions: Nullable[OCRPageDimensions]
    r"""The dimensions of the PDF Page's screenshot image"""

    tables: Optional[List[OCRTableObject]] = None
    r"""List of all extracted tables in the page"""

    hyperlinks: Optional[List[str]] = None
    r"""List of all hyperlinks in the page"""

    header: OptionalNullable[str] = UNSET
    r"""Header of the page"""

    footer: OptionalNullable[str] = UNSET
    r"""Footer of the page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["tables", "hyperlinks", "header", "footer"])
        nullable_fields = set(["header", "footer", "dimensions"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
