"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2dd61dcd7b48

from __future__ import annotations
from .jsonpayloadresponse import JSONPayloadResponse, JSONPayloadResponseTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowExecutionContinuedAsNewAttributesResponseTypedDict(TypedDict):
    r"""Attributes for workflow execution continued-as-new events."""

    task_id: str
    r"""Unique identifier for the task within the workflow execution."""
    new_execution_run_id: str
    r"""The run ID of the new workflow execution that continues this workflow."""
    workflow_name: str
    r"""The registered name of the continued workflow."""
    input: JSONPayloadResponseTypedDict
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """


class WorkflowExecutionContinuedAsNewAttributesResponse(BaseModel):
    r"""Attributes for workflow execution continued-as-new events."""

    task_id: str
    r"""Unique identifier for the task within the workflow execution."""

    new_execution_run_id: str
    r"""The run ID of the new workflow execution that continues this workflow."""

    workflow_name: str
    r"""The registered name of the continued workflow."""

    input: JSONPayloadResponse
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """
