"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5799cc4ab66e

from __future__ import annotations
from .updateinvocationbody import UpdateInvocationBody, UpdateInvocationBodyTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateWorkflowExecutionV1WorkflowsExecutionsExecutionIDUpdatesPostRequestTypedDict(
    TypedDict
):
    execution_id: str
    update_invocation_body: UpdateInvocationBodyTypedDict


class UpdateWorkflowExecutionV1WorkflowsExecutionsExecutionIDUpdatesPostRequest(
    BaseModel
):
    execution_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_invocation_body: Annotated[
        UpdateInvocationBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
