"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 25a6460a6e19

from __future__ import annotations
from .requestsource import RequestSource
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AgentsAPIV1AgentsListRequestTypedDict(TypedDict):
    page: NotRequired[int]
    r"""Page number (0-indexed)"""
    page_size: NotRequired[int]
    r"""Number of agents per page"""
    deployment_chat: NotRequired[Nullable[bool]]
    sources: NotRequired[Nullable[List[RequestSource]]]
    name: NotRequired[Nullable[str]]
    r"""Filter by agent name"""
    search: NotRequired[Nullable[str]]
    r"""Search agents by name or ID"""
    id: NotRequired[Nullable[str]]
    metadata: NotRequired[Nullable[Dict[str, Any]]]


class AgentsAPIV1AgentsListRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0
    r"""Page number (0-indexed)"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 20
    r"""Number of agents per page"""

    deployment_chat: Annotated[
        OptionalNullable[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    sources: Annotated[
        OptionalNullable[List[RequestSource]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    name: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by agent name"""

    search: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Search agents by name or ID"""

    id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    metadata: Annotated[
        OptionalNullable[Dict[str, Any]],
        FieldMetadata(query=QueryParamMetadata(serialization="json")),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "page",
                "page_size",
                "deployment_chat",
                "sources",
                "name",
                "search",
                "id",
                "metadata",
            ]
        )
        nullable_fields = set(
            ["deployment_chat", "sources", "name", "search", "id", "metadata"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
