"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6086dc081147

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic import ConfigDict
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal
from typing_extensions import Annotated, TypedDict


class TranscriptionStreamTextDeltaTypedDict(TypedDict):
    text: str
    type: Literal["transcription.text.delta"]


class TranscriptionStreamTextDelta(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    text: str

    type: Annotated[
        Annotated[
            Literal["transcription.text.delta"],
            AfterValidator(validate_const("transcription.text.delta")),
        ],
        pydantic.Field(alias="type"),
    ] = "transcription.text.delta"

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]


try:
    TranscriptionStreamTextDelta.model_rebuild()
except NameError:
    pass
