"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e6be9ec9e74c

from __future__ import annotations
from typing import Literal


SpeechOutputFormat = Literal[
    "pcm",
    "wav",
    "mp3",
    "flac",
    "opus",
]
