"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e5247c5183bb

from __future__ import annotations
from .scheduledefinitionoutput import (
    ScheduleDefinitionOutput,
    ScheduleDefinitionOutputTypedDict,
)
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class WorkflowScheduleListResponseTypedDict(TypedDict):
    schedules: List[ScheduleDefinitionOutputTypedDict]
    r"""A list of workflow schedules"""


class WorkflowScheduleListResponse(BaseModel):
    schedules: List[ScheduleDefinitionOutput]
    r"""A list of workflow schedules"""
