"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b11a9947bd19

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class DeploymentWorkerResponseTypedDict(TypedDict):
    name: str
    r"""Worker name"""
    created_at: datetime
    r"""When the worker first registered"""
    updated_at: datetime
    r"""When the worker last registered"""


class DeploymentWorkerResponse(BaseModel):
    name: str
    r"""Worker name"""

    created_at: datetime
    r"""When the worker first registered"""

    updated_at: datetime
    r"""When the worker last registered"""
