"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5e3448a39a40

from __future__ import annotations
from typing import Union
from typing_extensions import TypeAliasType


WorkflowExecutionTraceSummaryAttributesValuesTypedDict = TypeAliasType(
    "WorkflowExecutionTraceSummaryAttributesValuesTypedDict",
    Union[str, int, float, bool],
)


WorkflowExecutionTraceSummaryAttributesValues = TypeAliasType(
    "WorkflowExecutionTraceSummaryAttributesValues", Union[str, int, float, bool]
)
