"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: fa04e3db7781

from __future__ import annotations
from .judgeoutputtype import JudgeOutputType
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetJudgesV1ObservabilityJudgesGetRequestTypedDict(TypedDict):
    type_filter: NotRequired[Nullable[List[JudgeOutputType]]]
    r"""Filter by judge output types"""
    model_filter: NotRequired[Nullable[List[str]]]
    r"""Filter by model names"""
    page_size: NotRequired[int]
    page: NotRequired[int]
    q: NotRequired[Nullable[str]]


class GetJudgesV1ObservabilityJudgesGetRequest(BaseModel):
    type_filter: Annotated[
        OptionalNullable[List[JudgeOutputType]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by judge output types"""

    model_filter: Annotated[
        OptionalNullable[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by model names"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 50

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1

    q: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type_filter", "model_filter", "page_size", "page", "q"])
        nullable_fields = set(["type_filter", "model_filter", "q"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
