"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 475c805eab95

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FineTunedModelCapabilitiesTypedDict(TypedDict):
    completion_chat: NotRequired[bool]
    completion_fim: NotRequired[bool]
    function_calling: NotRequired[bool]
    fine_tuning: NotRequired[bool]
    classification: NotRequired[bool]


class FineTunedModelCapabilities(BaseModel):
    completion_chat: Optional[bool] = True

    completion_fim: Optional[bool] = False

    function_calling: Optional[bool] = False

    fine_tuning: Optional[bool] = False

    classification: Optional[bool] = False

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "completion_chat",
                "completion_fim",
                "function_calling",
                "fine_tuning",
                "classification",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
