"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 19c343844888

from __future__ import annotations
from .ftclassifierlossfunction import FTClassifierLossFunction
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ClassifierTargetResultTypedDict(TypedDict):
    name: str
    labels: List[str]
    weight: float
    loss_function: FTClassifierLossFunction


class ClassifierTargetResult(BaseModel):
    name: str

    labels: List[str]

    weight: float

    loss_function: FTClassifierLossFunction
