"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.azure.client.types import BaseModel, UnrecognizedStr
import pydantic
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


Format = Union[
    Literal[
        "markdown",
        "html",
    ],
    UnrecognizedStr,
]
r"""Format of the table"""


class OCRTableObjectTypedDict(TypedDict):
    id: str
    r"""Table ID for extracted table in a page"""
    content: str
    r"""Content of the table in the given format"""
    format_: Format
    r"""Format of the table"""


class OCRTableObject(BaseModel):
    id: str
    r"""Table ID for extracted table in a page"""

    content: str
    r"""Content of the table in the given format"""

    format_: Annotated[Format, pydantic.Field(alias="format")]
    r"""Format of the table"""


try:
    OCRTableObject.model_rebuild()
except NameError:
    pass
