"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 14518c40a13b

from __future__ import annotations
from mistralai.client.types import BaseModel
import pydantic
from pydantic import ConfigDict
from typing import Any, Dict
from typing_extensions import TypedDict


class ExecutionConfigTypedDict(TypedDict):
    r"""Not typed since mcp config can changed / not stable
    we allow all extra fields and this is a dict
    TODO: once mcp is stable, we need to type this
    """

    type: str


class ExecutionConfig(BaseModel):
    r"""Not typed since mcp config can changed / not stable
    we allow all extra fields and this is a dict
    TODO: once mcp is stable, we need to type this
    """

    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    type: str

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]
