"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b5819dd5f981

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ResourceVisibility = Union[
    Literal[
        "shared_global",
        "shared_org",
        "shared_workspace",
        "private",
    ],
    UnrecognizedStr,
]
