"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.azure.client.types import UnrecognizedStr
from typing import Literal, Union


ImageDetail = Union[
    Literal[
        "low",
        "auto",
        "high",
    ],
    UnrecognizedStr,
]
