"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2164b6526a81

from __future__ import annotations
from .usageinfo_dollar_defs import UsageInfoDollarDefs, UsageInfoDollarDefsTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class SpeechStreamDoneTypedDict(TypedDict):
    usage: UsageInfoDollarDefsTypedDict
    type: Literal["speech.audio.done"]


class SpeechStreamDone(BaseModel):
    usage: UsageInfoDollarDefs

    type: Annotated[
        Annotated[
            Literal["speech.audio.done"],
            AfterValidator(validate_const("speech.audio.done")),
        ],
        pydantic.Field(alias="type"),
    ] = "speech.audio.done"


try:
    SpeechStreamDone.model_rebuild()
except NameError:
    pass
