"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


BuiltInConnectors = Literal[
    "web_search",
    "web_search_premium",
    "code_interpreter",
    "image_generation",
    "document_library",
]
