"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 24d6a0861d4b

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ConversationSource = Union[
    Literal[
        "EXPLORER",
        "UPLOADED_FILE",
        "DIRECT_INPUT",
        "PLAYGROUND",
    ],
    UnrecognizedStr,
]
