"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 76db69eebe41

from __future__ import annotations
from .builtinconnectors import BuiltInConnectors
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


ToolExecutionEntryNameTypedDict = TypeAliasType(
    "ToolExecutionEntryNameTypedDict", Union[BuiltInConnectors, str]
)


ToolExecutionEntryName = TypeAliasType(
    "ToolExecutionEntryName", Union[BuiltInConnectors, str]
)


class ToolExecutionEntryTypedDict(TypedDict):
    name: ToolExecutionEntryNameTypedDict
    arguments: str
    object: Literal["entry"]
    type: Literal["tool.execution"]
    created_at: NotRequired[datetime]
    completed_at: NotRequired[Nullable[datetime]]
    agent_id: NotRequired[Nullable[str]]
    model: NotRequired[Nullable[str]]
    id: NotRequired[str]
    info: NotRequired[Dict[str, Any]]


class ToolExecutionEntry(BaseModel):
    name: ToolExecutionEntryName

    arguments: str

    object: Annotated[
        Annotated[Optional[Literal["entry"]], AfterValidator(validate_const("entry"))],
        pydantic.Field(alias="object"),
    ] = "entry"

    type: Annotated[
        Annotated[
            Optional[Literal["tool.execution"]],
            AfterValidator(validate_const("tool.execution")),
        ],
        pydantic.Field(alias="type"),
    ] = "tool.execution"

    created_at: Optional[datetime] = None

    completed_at: OptionalNullable[datetime] = UNSET

    agent_id: OptionalNullable[str] = UNSET

    model: OptionalNullable[str] = UNSET

    id: Optional[str] = None

    info: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "object",
                "type",
                "created_at",
                "completed_at",
                "agent_id",
                "model",
                "id",
                "info",
            ]
        )
        nullable_fields = set(["completed_at", "agent_id", "model"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    ToolExecutionEntry.model_rebuild()
except NameError:
    pass
