"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 26c8aadf416a

from __future__ import annotations
from .builtinconnectors import BuiltInConnectors
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


ToolFileChunkToolTypedDict = TypeAliasType(
    "ToolFileChunkToolTypedDict", Union[BuiltInConnectors, str]
)


ToolFileChunkTool = TypeAliasType("ToolFileChunkTool", Union[BuiltInConnectors, str])


class ToolFileChunkTypedDict(TypedDict):
    tool: ToolFileChunkToolTypedDict
    file_id: str
    type: Literal["tool_file"]
    file_name: NotRequired[Nullable[str]]
    file_type: NotRequired[Nullable[str]]


class ToolFileChunk(BaseModel):
    tool: ToolFileChunkTool

    file_id: str

    type: Annotated[
        Annotated[
            Optional[Literal["tool_file"]], AfterValidator(validate_const("tool_file"))
        ],
        pydantic.Field(alias="type"),
    ] = "tool_file"

    file_name: OptionalNullable[str] = UNSET

    file_type: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type", "file_name", "file_type"])
        nullable_fields = set(["file_name", "file_type"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    ToolFileChunk.model_rebuild()
except NameError:
    pass
