"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ce5dce4dced2

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class AudioChunkTypedDict(TypedDict):
    input_audio: str
    type: Literal["input_audio"]


class AudioChunk(BaseModel):
    input_audio: str

    type: Annotated[
        Annotated[
            Literal["input_audio"], AfterValidator(validate_const("input_audio"))
        ],
        pydantic.Field(alias="type"),
    ] = "input_audio"


try:
    AudioChunk.model_rebuild()
except NameError:
    pass
