"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cb6e8a484a38

from __future__ import annotations
from .observabilityerrorcode import ObservabilityErrorCode
from mistralai.client.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class ObservabilityErrorDetailTypedDict(TypedDict):
    message: str
    error_code: Nullable[ObservabilityErrorCode]


class ObservabilityErrorDetail(BaseModel):
    message: str

    error_code: Nullable[ObservabilityErrorCode]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
