"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f5918c34f1c7

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


AgentsAPIV1AgentsGetAgentVersionTypedDict = TypeAliasType(
    "AgentsAPIV1AgentsGetAgentVersionTypedDict", Union[int, str]
)


AgentsAPIV1AgentsGetAgentVersion = TypeAliasType(
    "AgentsAPIV1AgentsGetAgentVersion", Union[int, str]
)


class AgentsAPIV1AgentsGetRequestTypedDict(TypedDict):
    agent_id: str
    agent_version: NotRequired[Nullable[AgentsAPIV1AgentsGetAgentVersionTypedDict]]


class AgentsAPIV1AgentsGetRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    agent_version: Annotated[
        OptionalNullable[AgentsAPIV1AgentsGetAgentVersion],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["agent_version"])
        nullable_fields = set(["agent_version"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
