"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a5f0bad3ba10

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SearchChatCompletionEventIdsResponseTypedDict(TypedDict):
    completion_event_ids: List[str]


class SearchChatCompletionEventIdsResponse(BaseModel):
    completion_event_ids: List[str]
