"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e730005e44cb

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class DocumentTextContentTypedDict(TypedDict):
    text: str


class DocumentTextContent(BaseModel):
    text: str
