"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: d396e018c804

from __future__ import annotations
from .importdatasetfromdatasetrequest import (
    ImportDatasetFromDatasetRequest,
    ImportDatasetFromDatasetRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostDatasetRecordsFromDatasetV1ObservabilityDatasetsDatasetIDImportsFromDatasetPostRequestTypedDict(
    TypedDict
):
    dataset_id: str
    import_dataset_from_dataset_request: ImportDatasetFromDatasetRequestTypedDict


class PostDatasetRecordsFromDatasetV1ObservabilityDatasetsDatasetIDImportsFromDatasetPostRequest(
    BaseModel
):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    import_dataset_from_dataset_request: Annotated[
        ImportDatasetFromDatasetRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
