"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: bb511e7c628b

from __future__ import annotations
from .moderationllmaction import ModerationLLMAction
from .moderationllmv2categorythresholds import (
    ModerationLlmv2CategoryThresholds,
    ModerationLlmv2CategoryThresholdsTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ModerationLlmv2ConfigTypedDict(TypedDict):
    model_name: NotRequired[str]
    r"""Override model name. Should be omitted in general."""
    custom_category_thresholds: NotRequired[
        Nullable[ModerationLlmv2CategoryThresholdsTypedDict]
    ]
    ignore_other_categories: NotRequired[bool]
    r"""If true, only evaluate categories in custom_category_thresholds; others are ignored."""
    action: NotRequired[ModerationLLMAction]


class ModerationLlmv2Config(BaseModel):
    model_name: Optional[str] = "mistral-moderation-2603"
    r"""Override model name. Should be omitted in general."""

    custom_category_thresholds: OptionalNullable[ModerationLlmv2CategoryThresholds] = (
        UNSET
    )

    ignore_other_categories: Optional[bool] = False
    r"""If true, only evaluate categories in custom_category_thresholds; others are ignored."""

    action: Optional[ModerationLLMAction] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "model_name",
                "custom_category_thresholds",
                "ignore_other_categories",
                "action",
            ]
        )
        nullable_fields = set(["custom_category_thresholds"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
