"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 556ebdc33276

from __future__ import annotations
from .modelcapabilities import ModelCapabilities, ModelCapabilitiesTypedDict
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BaseModelCardTypedDict(TypedDict):
    id: str
    capabilities: ModelCapabilitiesTypedDict
    r"""This is populated by Harmattan, but some fields have a name
    that we don't want to expose in the API.
    """
    object: NotRequired[str]
    created: NotRequired[int]
    owned_by: NotRequired[str]
    name: NotRequired[Nullable[str]]
    description: NotRequired[Nullable[str]]
    max_context_length: NotRequired[int]
    aliases: NotRequired[List[str]]
    deprecation: NotRequired[Nullable[datetime]]
    deprecation_replacement_model: NotRequired[Nullable[str]]
    default_model_temperature: NotRequired[Nullable[float]]
    type: Literal["base"]


class BaseModelCard(BaseModel):
    id: str

    capabilities: ModelCapabilities
    r"""This is populated by Harmattan, but some fields have a name
    that we don't want to expose in the API.
    """

    object: Optional[str] = "model"

    created: Optional[int] = None

    owned_by: Optional[str] = "mistralai"

    name: OptionalNullable[str] = UNSET

    description: OptionalNullable[str] = UNSET

    max_context_length: Optional[int] = 32768

    aliases: Optional[List[str]] = None

    deprecation: OptionalNullable[datetime] = UNSET

    deprecation_replacement_model: OptionalNullable[str] = UNSET

    default_model_temperature: OptionalNullable[float] = UNSET

    type: Annotated[
        Annotated[Literal["base"], AfterValidator(validate_const("base"))],
        pydantic.Field(alias="type"),
    ] = "base"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "object",
                "created",
                "owned_by",
                "name",
                "description",
                "max_context_length",
                "aliases",
                "deprecation",
                "deprecation_replacement_model",
                "default_model_temperature",
            ]
        )
        nullable_fields = set(
            [
                "name",
                "description",
                "deprecation",
                "deprecation_replacement_model",
                "default_model_temperature",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    BaseModelCard.model_rebuild()
except NameError:
    pass
