"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 77aea4882ccb

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ImportDatasetFromDatasetRequestTypedDict(TypedDict):
    dataset_record_ids: List[str]


class ImportDatasetFromDatasetRequest(BaseModel):
    dataset_record_ids: List[str]
