"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 73ca3a446dcc

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorGetV1RequestTypedDict(TypedDict):
    connector_id_or_name: str
    fetch_customer_data: NotRequired[bool]
    r"""Fetch the customer data associated with the connector (e.g. customer secrets / config)."""
    fetch_connection_secrets: NotRequired[bool]
    r"""Fetch the general connection secrets associated with the connector."""


class ConnectorGetV1Request(BaseModel):
    connector_id_or_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    fetch_customer_data: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""Fetch the customer data associated with the connector (e.g. customer secrets / config)."""

    fetch_connection_secrets: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""Fetch the general connection secrets associated with the connector."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["fetch_customer_data", "fetch_connection_secrets"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
