"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ac66815396b1

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class SpeechStreamAudioDeltaTypedDict(TypedDict):
    audio_data: str
    type: Literal["speech.audio.delta"]


class SpeechStreamAudioDelta(BaseModel):
    audio_data: str

    type: Annotated[
        Annotated[
            Literal["speech.audio.delta"],
            AfterValidator(validate_const("speech.audio.delta")),
        ],
        pydantic.Field(alias="type"),
    ] = "speech.audio.delta"


try:
    SpeechStreamAudioDelta.model_rebuild()
except NameError:
    pass
