"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 06bab279cb31

from __future__ import annotations
from .moderationobject import ModerationObject, ModerationObjectTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ModerationResponseTypedDict(TypedDict):
    id: str
    model: str
    results: List[ModerationObjectTypedDict]


class ModerationResponse(BaseModel):
    id: str

    model: str

    results: List[ModerationObject]
