"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e41c04cf7422

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


Roles = Union[
    Literal[
        "system",
        "user",
        "assistant",
        "tool",
    ],
    UnrecognizedStr,
]
