"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 98dd1b838524

from __future__ import annotations
from .tempotraceattribute import TempoTraceAttribute, TempoTraceAttributeTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TempoTraceEventTypedDict(TypedDict):
    name: str
    r"""The name of the event"""
    time_unix_nano: str
    r"""The time of the event in Unix nano"""
    attributes: NotRequired[List[TempoTraceAttributeTypedDict]]
    r"""The attributes of the event"""


class TempoTraceEvent(BaseModel):
    name: str
    r"""The name of the event"""

    time_unix_nano: Annotated[str, pydantic.Field(alias="timeUnixNano")]
    r"""The time of the event in Unix nano"""

    attributes: Optional[List[TempoTraceAttribute]] = None
    r"""The attributes of the event"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["attributes"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TempoTraceEvent.model_rebuild()
except NameError:
    pass
