"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b14e6a50f730

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


AudioEncoding = Union[
    Literal[
        "pcm_s16le",
        "pcm_s32le",
        "pcm_f16le",
        "pcm_f32le",
        "pcm_mulaw",
        "pcm_alaw",
    ],
    UnrecognizedStr,
]
