"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: d21e2a36ab1f

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


FTClassifierLossFunction = Union[
    Literal[
        "single_class",
        "multi_class",
    ],
    UnrecognizedStr,
]
