"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2dcdd05a5115

from __future__ import annotations
from mistralai.client.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TempoTraceAttributeStringValueTypedDict(TypedDict):
    string_value: str
    r"""The string value of the attribute"""


class TempoTraceAttributeStringValue(BaseModel):
    string_value: Annotated[str, pydantic.Field(alias="stringValue")]
    r"""The string value of the attribute"""


try:
    TempoTraceAttributeStringValue.model_rebuild()
except NameError:
    pass
