"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6b8946c77018

from __future__ import annotations
from .jsonpayloadresponse import JSONPayloadResponse, JSONPayloadResponseTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CustomTaskStartedAttributesResponseTypedDict(TypedDict):
    r"""Attributes for custom task started events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""
    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""
    payload: NotRequired[JSONPayloadResponseTypedDict]
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """


class CustomTaskStartedAttributesResponse(BaseModel):
    r"""Attributes for custom task started events."""

    custom_task_id: str
    r"""Unique identifier for the custom task within the workflow."""

    custom_task_type: str
    r"""The type/category of the custom task (e.g., 'llm_call', 'api_request')."""

    payload: Optional[JSONPayloadResponse] = None
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["payload"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
