"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 73826dbd3f5b

from __future__ import annotations
from .queryinvocationbody import QueryInvocationBody, QueryInvocationBodyTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class QueryWorkflowExecutionV1WorkflowsExecutionsExecutionIDQueriesPostRequestTypedDict(
    TypedDict
):
    execution_id: str
    query_invocation_body: QueryInvocationBodyTypedDict


class QueryWorkflowExecutionV1WorkflowsExecutionsExecutionIDQueriesPostRequest(
    BaseModel
):
    execution_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    query_invocation_body: Annotated[
        QueryInvocationBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
