"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 22e2ccbb0c80

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UnarchiveModelResponseTypedDict(TypedDict):
    id: str
    object: Literal["model"]
    archived: NotRequired[bool]


class UnarchiveModelResponse(BaseModel):
    id: str

    object: Annotated[
        Annotated[Optional[Literal["model"]], AfterValidator(validate_const("model"))],
        pydantic.Field(alias="object"),
    ] = "model"

    archived: Optional[bool] = False

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object", "archived"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    UnarchiveModelResponse.model_rebuild()
except NameError:
    pass
