"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: bd45f357a538

from __future__ import annotations
from .conversationpayload import ConversationPayload, ConversationPayloadTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class UpdateDatasetRecordPayloadRequestTypedDict(TypedDict):
    payload: ConversationPayloadTypedDict


class UpdateDatasetRecordPayloadRequest(BaseModel):
    payload: ConversationPayload
