"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 046c79ed47c7

from __future__ import annotations
from .importdatasetfromexplorerrequest import (
    ImportDatasetFromExplorerRequest,
    ImportDatasetFromExplorerRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostDatasetRecordsFromExplorerV1ObservabilityDatasetsDatasetIDImportsFromExplorerPostRequestTypedDict(
    TypedDict
):
    dataset_id: str
    import_dataset_from_explorer_request: ImportDatasetFromExplorerRequestTypedDict


class PostDatasetRecordsFromExplorerV1ObservabilityDatasetsDatasetIDImportsFromExplorerPostRequest(
    BaseModel
):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    import_dataset_from_explorer_request: Annotated[
        ImportDatasetFromExplorerRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
