"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5b707a343930

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class FieldOptionCountItemTypedDict(TypedDict):
    value: str
    count: int


class FieldOptionCountItem(BaseModel):
    value: str

    count: int
