"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8c8099403e62

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


AnswerTypedDict = TypeAliasType("AnswerTypedDict", Union[str, float])


Answer = TypeAliasType("Answer", Union[str, float])


class JudgeOutputTypedDict(TypedDict):
    analysis: str
    answer: AnswerTypedDict


class JudgeOutput(BaseModel):
    analysis: str

    answer: Answer
