"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 16ce9431fc7b

from __future__ import annotations
from .fieldoptioncountitem import FieldOptionCountItem, FieldOptionCountItemTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class FetchFieldOptionCountsResponseTypedDict(TypedDict):
    counts: List[FieldOptionCountItemTypedDict]


class FetchFieldOptionCountsResponse(BaseModel):
    counts: List[FieldOptionCountItem]
