"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 37e6d5d616fe

from __future__ import annotations
from .batchexecutionresult import BatchExecutionResult, BatchExecutionResultTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class BatchExecutionResponseTypedDict(TypedDict):
    results: NotRequired[Dict[str, BatchExecutionResultTypedDict]]
    r"""Mapping of execution_id to result with status and optional error message"""


class BatchExecutionResponse(BaseModel):
    results: Optional[Dict[str, BatchExecutionResult]] = None
    r"""Mapping of execution_id to result with status and optional error message"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["results"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
