"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 56757b849f7a

from __future__ import annotations
from .filtercondition import FilterCondition, FilterConditionTypedDict
from .filtergroup import FilterGroup, FilterGroupTypedDict
from mistralai.client.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


FiltersTypedDict = TypeAliasType(
    "FiltersTypedDict", Union[FilterGroupTypedDict, FilterConditionTypedDict]
)


Filters = TypeAliasType("Filters", Union[FilterGroup, FilterCondition])


class FilterPayloadTypedDict(TypedDict):
    filters: Nullable[FiltersTypedDict]


class FilterPayload(BaseModel):
    filters: Nullable[Filters]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
