"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a11e7f9f2d45

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


FilePurpose = Union[
    Literal[
        "fine-tune",
        "batch",
        "ocr",
    ],
    UnrecognizedStr,
]
