"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 97955ebc2eb9

from __future__ import annotations
from typing import Literal


EncodedPayloadOptions = Literal[
    "offloaded",
    "encrypted",
    "encrypted-partial",
]
