"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5c1f1109aa5e

from .basesdk import BaseSDK
from enum import Enum
from mistralai.client import errors, models, utils
from mistralai.client._hooks import HookContext
from mistralai.client.types import OptionalNullable, UNSET
from mistralai.client.utils import eventstreaming, get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, Literal, Mapping, Optional, Union, overload


class CompleteAcceptEnum(str, Enum):
    APPLICATION_JSON = "application/json"
    TEXT_EVENT_STREAM = "text/event-stream"


class Speech(BaseSDK):
    @overload
    def complete(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Union[Literal[False], None] = None,
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SpeechResponse:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    def complete(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Literal[True],
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[models.SpeechStreamEvents]:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    def complete(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Optional[bool] = False,
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SpeechV1AudioSpeechPostResponse:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SpeechRequest(
            model=model,
            metadata=utils.get_pydantic_model(
                metadata, OptionalNullable[models.MetadataDict]
            ),
            stream=stream,
            voice_id=voice_id,
            ref_audio=ref_audio,
            input=input,
            response_format=response_format,
            **(additional_properties or {}),
        )

        req = self._build_request(
            method="POST",
            path="/v1/audio/speech",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SpeechRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="speech_v1_audio_speech_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            return unmarshal_json_response(
                models.SpeechResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStream(
                http_res,
                lambda raw: utils.unmarshal_json(raw, models.SpeechStreamEvents),
                client_ref=self,
            )
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res, http_res_text
            )
            raise errors.HTTPValidationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError("Unexpected response received", http_res, http_res_text)

    @overload
    async def complete_async(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Union[Literal[False], None] = None,
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SpeechResponse:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    async def complete_async(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Literal[True],
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[models.SpeechStreamEvents]:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    async def complete_async(
        self,
        *,
        input: str,
        model: OptionalNullable[str] = UNSET,
        metadata: OptionalNullable[
            Union[models.MetadataDict, models.MetadataDictTypedDict]
        ] = UNSET,
        stream: Optional[bool] = False,
        voice_id: OptionalNullable[str] = UNSET,
        ref_audio: OptionalNullable[str] = UNSET,
        response_format: Optional[models.SpeechOutputFormat] = None,
        additional_properties: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SpeechV1AudioSpeechPostResponse:
        r"""Speech

        :param input: Text to generate a speech from
        :param model:
        :param metadata:
        :param stream:
        :param voice_id: The preset or custom voice to use for generating the speech.
        :param ref_audio: The audio reference for generating the speech.
        :param response_format:
        :param additional_properties:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SpeechRequest(
            model=model,
            metadata=utils.get_pydantic_model(
                metadata, OptionalNullable[models.MetadataDict]
            ),
            stream=stream,
            voice_id=voice_id,
            ref_audio=ref_audio,
            input=input,
            response_format=response_format,
            **(additional_properties or {}),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/audio/speech",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SpeechRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="speech_v1_audio_speech_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            return unmarshal_json_response(
                models.SpeechResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStreamAsync(
                http_res,
                lambda raw: utils.unmarshal_json(raw, models.SpeechStreamEvents),
                client_ref=self,
            )
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res, http_res_text
            )
            raise errors.HTTPValidationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError("Unexpected response received", http_res, http_res_text)
