"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8174941767cc

from __future__ import annotations
from .jsonpayloadresponse import JSONPayloadResponse, JSONPayloadResponseTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ActivityTaskCompletedAttributesResponseTypedDict(TypedDict):
    r"""Attributes for activity task completed events."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""
    activity_name: str
    r"""The registered name of the activity being executed."""
    result: JSONPayloadResponseTypedDict
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """


class ActivityTaskCompletedAttributesResponse(BaseModel):
    r"""Attributes for activity task completed events."""

    task_id: str
    r"""Unique identifier for the activity task within the workflow."""

    activity_name: str
    r"""The registered name of the activity being executed."""

    result: JSONPayloadResponse
    r"""A payload containing arbitrary JSON data.

    Used for complete state snapshots or final results.
    """
