"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 11a670fa3b71

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


FileVisibility = Union[
    Literal[
        "workspace",
        "user",
    ],
    UnrecognizedStr,
]
