"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 28146eaecfcf

from __future__ import annotations
from .processstatus import ProcessStatus
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class ProcessingStatusTypedDict(TypedDict):
    document_id: str
    process_status: ProcessStatus
    processing_status: str


class ProcessingStatus(BaseModel):
    document_id: str

    process_status: ProcessStatus

    processing_status: str
