"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b930a0a20654

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ReasoningEffort = Union[
    Literal[
        "none",
        "high",
    ],
    UnrecognizedStr,
]
