"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 68ddf8d702ea

from __future__ import annotations
from typing import Literal


TimestampGranularity = Literal[
    "segment",
    "word",
]
