"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c187ba1b551d

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class RealtimeTranscriptionInputAudioEndTypedDict(TypedDict):
    type: Literal["input_audio.end"]


class RealtimeTranscriptionInputAudioEnd(BaseModel):
    type: Annotated[
        Annotated[
            Optional[Literal["input_audio.end"]],
            AfterValidator(validate_const("input_audio.end")),
        ],
        pydantic.Field(alias="type"),
    ] = "input_audio.end"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    RealtimeTranscriptionInputAudioEnd.model_rebuild()
except NameError:
    pass
