"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c8655712c218

from __future__ import annotations
from .audioencoding import AudioEncoding
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AudioFormatTypedDict(TypedDict):
    encoding: AudioEncoding
    sample_rate: int


class AudioFormat(BaseModel):
    encoding: AudioEncoding

    sample_rate: int
