"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7f91751795ac

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import List, Union
from typing_extensions import TypeAliasType, TypedDict


TimeSeriesMetricValue1TypedDict = TypeAliasType(
    "TimeSeriesMetricValue1TypedDict", Union[int, float]
)


TimeSeriesMetricValue1 = TypeAliasType("TimeSeriesMetricValue1", Union[int, float])


TimeSeriesMetricValue2TypedDict = TypeAliasType(
    "TimeSeriesMetricValue2TypedDict", Union[int, TimeSeriesMetricValue1TypedDict]
)


TimeSeriesMetricValue2 = TypeAliasType(
    "TimeSeriesMetricValue2", Union[int, TimeSeriesMetricValue1]
)


class TimeSeriesMetricTypedDict(TypedDict):
    r"""Time-series metric with timestamp-value pairs."""

    value: List[List[TimeSeriesMetricValue2TypedDict]]


class TimeSeriesMetric(BaseModel):
    r"""Time-series metric with timestamp-value pairs."""

    value: List[List[TimeSeriesMetricValue2]]
