"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6f884d18ac56

from __future__ import annotations
from .updateconnectorrequest import (
    UpdateConnectorRequest,
    UpdateConnectorRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ConnectorUpdateV1RequestTypedDict(TypedDict):
    connector_id: str
    update_connector_request: UpdateConnectorRequestTypedDict


class ConnectorUpdateV1Request(BaseModel):
    connector_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_connector_request: Annotated[
        UpdateConnectorRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
