"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3e9d229cd8ba

from __future__ import annotations
from .resetinvocationbody import ResetInvocationBody, ResetInvocationBodyTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ResetWorkflowV1WorkflowsExecutionsExecutionIDResetPostRequestTypedDict(TypedDict):
    execution_id: str
    reset_invocation_body: ResetInvocationBodyTypedDict


class ResetWorkflowV1WorkflowsExecutionsExecutionIDResetPostRequest(BaseModel):
    execution_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    reset_invocation_body: Annotated[
        ResetInvocationBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
