"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3f2774d9e609

from __future__ import annotations
from typing import Literal


RequestSource = Literal[
    "api",
    "playground",
    "agent_builder_v1",
]
