"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c238f17d786b

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class JudgeClassificationOutputOptionTypedDict(TypedDict):
    value: str
    description: str


class JudgeClassificationOutputOption(BaseModel):
    value: str

    description: str
