"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 4749566fd16d

from __future__ import annotations
from .judgedatasetrecordrequest import (
    JudgeDatasetRecordRequest,
    JudgeDatasetRecordRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class JudgeDatasetRecordV1ObservabilityDatasetRecordsDatasetRecordIDLiveJudgingPostRequestTypedDict(
    TypedDict
):
    dataset_record_id: str
    judge_dataset_record_request: JudgeDatasetRecordRequestTypedDict


class JudgeDatasetRecordV1ObservabilityDatasetRecordsDatasetRecordIDLiveJudgingPostRequest(
    BaseModel
):
    dataset_record_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    judge_dataset_record_request: Annotated[
        JudgeDatasetRecordRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
