"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 77f9526a78df

from __future__ import annotations
from typing import Literal


EmbeddingDtype = Literal[
    "float",
    "int8",
    "uint8",
    "binary",
    "ubinary",
]
