"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2f8837a6a5c3

from __future__ import annotations
from .basefielddefinition import BaseFieldDefinition, BaseFieldDefinitionTypedDict
from .fieldgroup import FieldGroup, FieldGroupTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListChatCompletionFieldsResponseTypedDict(TypedDict):
    field_definitions: List[BaseFieldDefinitionTypedDict]
    field_groups: List[FieldGroupTypedDict]


class ListChatCompletionFieldsResponse(BaseModel):
    field_definitions: List[BaseFieldDefinition]

    field_groups: List[FieldGroup]
