"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: dbc0c34fbc2f

from __future__ import annotations
from .filtercondition import FilterCondition, FilterConditionTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class FilterGroupTypedDict(TypedDict):
    and_: NotRequired[Nullable[List[AndTypedDict]]]
    or_: NotRequired[Nullable[List[OrTypedDict]]]


class FilterGroup(BaseModel):
    and_: Annotated[OptionalNullable[List[And]], pydantic.Field(alias="AND")] = UNSET

    or_: Annotated[OptionalNullable[List[Or]], pydantic.Field(alias="OR")] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["AND", "OR"])
        nullable_fields = set(["AND", "OR"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


OrTypedDict = TypeAliasType(
    "OrTypedDict", Union["FilterGroupTypedDict", FilterConditionTypedDict]
)


Or = TypeAliasType("Or", Union["FilterGroup", FilterCondition])


AndTypedDict = TypeAliasType(
    "AndTypedDict", Union["FilterGroupTypedDict", FilterConditionTypedDict]
)


And = TypeAliasType("And", Union["FilterGroup", FilterCondition])


try:
    FilterGroup.model_rebuild()
except NameError:
    pass
