"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a729c26f9c43

from __future__ import annotations
from mistralai.client.types import UnrecognizedInt
from typing import Literal, Union


ScheduleOverlapPolicy = Union[
    Literal[
        1,
        2,
        3,
        4,
        5,
        6,
    ],
    UnrecognizedInt,
]
r"""Controls what happens when a workflow would be started by a schedule but
one is already running.
"""
