"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 596e38493eaa

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class FailureTypedDict(TypedDict):
    r"""Represents an error or exception that occurred during execution."""

    message: str
    r"""A human-readable description of the failure."""


class Failure(BaseModel):
    r"""Represents an error or exception that occurred during execution."""

    message: str
    r"""A human-readable description of the failure."""
