"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5f339214501d

from __future__ import annotations
from typing import List, Union
from typing_extensions import TypeAliasType


CompletionArgsStopTypedDict = TypeAliasType(
    "CompletionArgsStopTypedDict", Union[str, List[str]]
)


CompletionArgsStop = TypeAliasType("CompletionArgsStop", Union[str, List[str]])
