"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 487c6addf089

from __future__ import annotations
from .sharing import Sharing, SharingTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListSharingResponseTypedDict(TypedDict):
    data: List[SharingTypedDict]


class ListSharingResponse(BaseModel):
    data: List[Sharing]
