"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: d543506af998

from __future__ import annotations
from .prompttokensdetails import PromptTokensDetails, PromptTokensDetailsTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UsageInfoDollarDefsTypedDict(TypedDict):
    prompt_audio_seconds: NotRequired[Nullable[int]]
    prompt_tokens: NotRequired[int]
    total_tokens: NotRequired[int]
    completion_tokens: NotRequired[Nullable[int]]
    request_count: NotRequired[Nullable[int]]
    prompt_tokens_details: NotRequired[Nullable[PromptTokensDetailsTypedDict]]
    prompt_token_details: NotRequired[Nullable[PromptTokensDetailsTypedDict]]
    num_cached_tokens: NotRequired[Nullable[int]]


class UsageInfoDollarDefs(BaseModel):
    prompt_audio_seconds: OptionalNullable[int] = UNSET

    prompt_tokens: Optional[int] = 0

    total_tokens: Optional[int] = 0

    completion_tokens: OptionalNullable[int] = UNSET

    request_count: OptionalNullable[int] = UNSET

    prompt_tokens_details: OptionalNullable[PromptTokensDetails] = UNSET

    prompt_token_details: OptionalNullable[PromptTokensDetails] = UNSET

    num_cached_tokens: OptionalNullable[int] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "prompt_audio_seconds",
                "prompt_tokens",
                "total_tokens",
                "completion_tokens",
                "request_count",
                "prompt_tokens_details",
                "prompt_token_details",
                "num_cached_tokens",
            ]
        )
        nullable_fields = set(
            [
                "prompt_audio_seconds",
                "completion_tokens",
                "request_count",
                "prompt_tokens_details",
                "prompt_token_details",
                "num_cached_tokens",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
