"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7bb459765cba

from __future__ import annotations
from .updatedatasetrequest import UpdateDatasetRequest, UpdateDatasetRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateDatasetV1ObservabilityDatasetsDatasetIDPatchRequestTypedDict(TypedDict):
    dataset_id: str
    update_dataset_request: UpdateDatasetRequestTypedDict


class UpdateDatasetV1ObservabilityDatasetsDatasetIDPatchRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_dataset_request: Annotated[
        UpdateDatasetRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
